@@ -20,7 +20,6 @@
 
 #include "galeon.h"
 
-
 typedef struct
 {
 	POA_Galeon_Browser servant;
@@ -37,7 +36,7 @@ Galeon_Browser impl_Galeon_Browser__create(	PortableServer_POA poa,
 static CORBA_boolean
 impl_Galeon_Browser_loadurl(impl_POA_Galeon_Browser * servant,
 		 	     CORBA_char * url,
-			     CORBA_boolean newwin,
+			     Galeon_ViewState viewstate,
 			     CORBA_Environment * ev);
 
 static CORBA_boolean
@@ -98,38 +97,37 @@ impl_Galeon_Browser__create(PortableServer_POA poa, CORBA_Environment * ev)
 static CORBA_boolean
 impl_Galeon_Browser_loadurl(impl_POA_Galeon_Browser * servant,
 			  CORBA_char * url,
-			  CORBA_boolean newwin,
+			  Galeon_ViewState viewstate,
 			  CORBA_Environment * ev)
 {
 	CORBA_boolean retval = TRUE;
-	gboolean tabbed_mode, new_window;
+	gboolean tabbed_mode;  /* user pref              */
+	gboolean new_win;      /* for embed_create_*()   */
 	GaleonEmbed *ge;
 
-	/* FIXME: a mess, I've probably got it worng 10/2/2001 -- mpa */
-
 	tabbed_mode = gnome_config_get_bool (CONF_APPEARANCE_TABBED);
 
 #ifdef DEBUG_CORBA	
-	g_print("CORBA: loadurl(%s)\n", url);
+	g_print("CORBA: loadurl(%s, %d)\n", url, viewstate);
 #endif
 	
+	/* FIXME: this logic of using the last embed is not ideal - Nate */
 	ge = (all_embeds == NULL ? NULL : g_list_last (all_embeds)->data);
-	if (newwin == TRUE || ge == NULL)
+
+	new_win = (viewstate == Galeon_WINDOW) || (viewstate == Galeon_DEFAULT && !tabbed_mode);
+	
+	switch (viewstate)
 	{
-		new_window = (ge == NULL || !tabbed_mode);
-		if (strlen(url))
-		{
-			embed_create_from_url (ge, url, new_window);
-		}
-		else
-		{
-			embed_create_default (ge, new_window);
-		}
-	}
-	else
-	{
-		embed_load_url(ge, url);
-	}
+		case Galeon_NONE: if (ge != NULL) embed_load_url(ge, url);
+				  break;
+		case Galeon_DEFAULT:
+		case Galeon_WINDOW:
+		case Galeon_TAB:  if (strlen(url))
+					 embed_create_from_url(ge, url, new_win);
+		    		  else
+					 embed_create_default(ge, new_win);
+				  break;
+	}	 
 	
 	return retval;
 }
