@@ -1073,10 +1073,11 @@ bookmarks_remove_menu_global (void)
 	/* Destroys the menus */
 	for (sl = all_windows; sl != NULL; sl = sl->next) {
 		GtkWidget *WMain = ( (GaleonWindow*) sl->data)->WMain;
-		GtkWidget *separator = glade_lookup_widget
-			(WMain, "bookmarks_separator");
+		GtkWidget *separator = gtk_object_get_data (GTK_OBJECT(WMain),
+							"bookmarks_separator");
 		GList *l = gtk_container_children (GTK_CONTAINER (
-			glade_lookup_widget (WMain, "bookmarks_menu")));
+				gtk_object_get_data (GTK_OBJECT(WMain),
+						     "bookmarks_menu")));
 		GList *li;
 		/* first look for the separator */
 		for (li = l; li != NULL; li = li->next) {
@@ -1205,7 +1206,7 @@ bookmarks_create_file_submenu (GtkMenuItem *file_menuitem,
 	gtk_menu_item_set_submenu
 		(GTK_MENU_ITEM (file_menuitem),
 		 file_menu);
-	
+
 	w = bookmarks_create_menu_item (bookmark);
 	gtk_signal_connect (GTK_OBJECT (w), "activate", 
 			    bookmarks_file_bookmark_cb, bookmark);
@@ -1312,9 +1313,9 @@ bookmarks_create_menu (GaleonWindow *window)
 {
 	GtkWidget *app = window->WMain;
 	GtkMenu *menu = GTK_MENU
-		(glade_lookup_widget (app, "bookmarks_menu"));
+		(gtk_object_get_data (GTK_OBJECT(app), "bookmarks_menu"));
 	GtkMenuItem *file_menuitem = GTK_MENU_ITEM 
-		(glade_lookup_widget (app, "file_bookmark"));
+		(gtk_object_get_data (GTK_OBJECT(app), "file_bookmark"));
 	if (window->bookmarks_tooltips) 
 		gtk_object_destroy (GTK_OBJECT (window->bookmarks_tooltips));
 	window->bookmarks_tooltips = gtk_tooltips_new ();
@@ -1327,8 +1328,7 @@ bookmarks_create_menu (GaleonWindow *window)
 void 
 bookmarks_create_tb (GaleonWindow *window)
 {
-	gboolean visible = GTK_CHECK_MENU_ITEM 
-		(glade_lookup_widget (window->WMain, "view_toolbar"))->active;
+	gboolean visible = GTK_CHECK_MENU_ITEM (window->view_toolbar)->active;
 	bookmarks_create_toolbars (window, bookmarks_root);
 	bookmarks_toolbar_set_visible (window, visible);
 }
@@ -1442,7 +1442,7 @@ bookmarks_move_bookmark (bookmarks_editor_controls *controls, BookMarkItem *b, i
 static void 
 bookmarks_toolbar_clicked (GtkButton *button, gpointer user_data)
 {
-	GtkWidget *WMain = glade_lookup_widget (GTK_WIDGET (button),"WMain");
+	GtkWidget *WMain = window_lookup_wmain (GTK_WIDGET(button));
 	GaleonWindow *window =  gtk_object_get_data(GTK_OBJECT(WMain), 
 						    "GaleonWindow");
 	BookMarkItem *bi = user_data;
@@ -1452,11 +1452,12 @@ bookmarks_toolbar_clicked (GtkButton *button, gpointer user_data)
 		GtkWidget *menu = gtk_menu_new();
 		GtkTooltips *tooltips = gtk_tooltips_new ();
 		
-		bookmarks_create_menu_recursively(bi, GTK_MENU (menu), NULL, tooltips);
-		
-		/* see glade_lookup_widget for an explanation of the following */
-		gtk_object_set_data (GTK_OBJECT(menu), "widget_tree", 
-				     glade_get_widget_tree(WMain));
+		bookmarks_create_menu_recursively(bi, GTK_MENU (menu), NULL,
+						  tooltips);
+
+		/* attach "WMain" to the menu so it can be looked up later */
+		gtk_object_set_data(GTK_OBJECT(menu), "WMain", WMain);
+
 		gnome_popup_menu_do_popup_modal(menu, menu_position_under_widget,
 						button, NULL, NULL);
 		gtk_widget_destroy (menu);
@@ -1474,7 +1475,7 @@ bookmarks_button_release_event (GtkWidget *widget, GdkEventButton *event,
 {
 	BookMarkItem *bi = user_data;
 	/* FIXME: ugh */
-	GtkWidget *WMain = glade_lookup_widget (GTK_WIDGET (widget), "WMain");
+	GtkWidget *WMain = window_lookup_wmain (widget);
 	GaleonWindow *window =  gtk_object_get_data(GTK_OBJECT (WMain), 
 						    "GaleonWindow");
 	gboolean tabbed_mode;
