@@ -222,13 +222,17 @@ void
 bookmarks_import_mozilla_activate_cb (GtkMenuItem *menuitem, GaleonWindow *window)
 {
 	GString * fname = g_string_new (NULL);
+	char *prefs_dir = get_mozilla_prefs_directory();
 
-	g_string_assign (fname, g_get_home_dir ());
-	g_string_append (fname, MOZILLA_BOOKMARKS);
+	if (!prefs_dir) return;
+
+	g_string_assign (fname, prefs_dir);
+	g_string_append (fname, "/bookmarks.html");
 
 	bookmarks_import_netscape_style(window, fname);
 
 	g_string_free (fname, TRUE);
+	g_free (prefs_dir);
 }
 
 void
@@ -279,7 +283,7 @@ bookmarks_file_bookmark_cb (GtkMenuItem *menuitem, BookMarkItem *p)
 	GaleonEmbed *embed;
 	gchar *url, *name;
 
-	WMain = glade_lookup_widget (GTK_WIDGET (menuitem), "WMain");
+	WMain = window_lookup_wmain (GTK_WIDGET (menuitem));
 	window = gtk_object_get_data (GTK_OBJECT (WMain), "GaleonWindow");
 	return_if_not_window (window);
 	embed = window->active_embed;
@@ -329,14 +333,14 @@ bookmarks_export_netscape_activate_cb (GtkMenuItem *menuitem, GaleonWindow *wind
 void
 bookmarks_export_mozilla_activate_cb (GtkMenuItem *menuitem, GaleonWindow *window)
 {
-	GString *fname = g_string_new (NULL);
+	char *fname;
+	char *prefs_dir = get_mozilla_prefs_directory();
 
-	g_string_assign (fname, g_get_home_dir ());
-	g_string_append (fname, MOZILLA_BOOKMARKS);
+	fname = g_strconcat (prefs_dir,"/bookmarks.html", NULL);
+	g_print (fname);
+	bookmark_export_netscape_message (window, fname);
 
-	bookmark_export_netscape_message (window, fname->str);
-
-	g_string_free (fname, FALSE);
+	g_free (prefs_dir);
 }
 
 void
@@ -1078,7 +1082,9 @@ bookmarks_editor_ctree_button_press_event_cb (GtkWidget *widget, GdkEventButton
 		(GTK_CTREE (widget), gtk_ctree_node_nth (GTK_CTREE (widget), row));
 
 	/* Double click goes to the link */
-	if (event->type == GDK_2BUTTON_PRESS) {
+	if (event->type == GDK_2BUTTON_PRESS && 
+	    controls->last_pressed != NULL)
+	{
 		/* make sure that this entry is selected */
 		gtk_ctree_select (GTK_CTREE (controls->ctree),
 				  controls->last_pressed->tree_item);
@@ -1099,7 +1105,12 @@ bookmarks_editor_ctree_key_press_event_cb (GtkWidget *widget,
 		    event->keyval == GDK_KP_Delete)
 			bookmarks_editor_remove_clicked_cb(NULL, controls);
 	}
-	else if (event->state == KEY_CODE)
+	else if ( (event->state & GDK_LOCK_MASK ||
+		   event->state & GDK_MOD2_MASK ||
+		   event->state & GDK_MOD5_MASK) &&
+		 !(event->state & GDK_SHIFT_MASK ||
+		   event->state & GDK_MOD1_MASK  ||
+		   event->state & GDK_CONTROL_MASK) )
 	{
 		if (event->keyval == GDK_Delete)
 			bookmarks_editor_remove_clicked_cb(NULL, controls);
