@@ -24,6 +24,7 @@ static void embed_set_notebook_label (GaleonEmbed *embed,
 static GtkWidget *embed_notebook_label_new (GaleonEmbed *embed,
 					    const gchar *label);
 static GaleonEmbed *embed_create (GaleonEmbed *previous, gboolean new_window);
+static gchar *embed_get_save_file_name (gchar *url);
 
 /** The global list of all GaleonEmbed structures */
 GList *all_embeds = NULL;
@@ -125,6 +126,7 @@ embed_set_visibility (GaleonEmbed *embed, gboolean visibility)
 	{
 		/* showing */
 		window->visible_embeds++;
+		embed->is_visible = TRUE;
 		set_settings_menu_window (window);
 		gtk_widget_show (window->WMain);
 	}
@@ -132,14 +134,12 @@ embed_set_visibility (GaleonEmbed *embed, gboolean visibility)
 	{
 		/* hiding */
 		window->visible_embeds--;
+		embed->is_visible = FALSE;
 		if (window->visible_embeds == 0)
 		{
 			gtk_widget_hide (window->WMain);
 		}
 	}
-
-	/* update status */
-	embed->is_visible = visibility;
 }
 
 /**
@@ -166,10 +166,8 @@ embed_load_url (GaleonEmbed *embed, const gchar *url)
 	}
 	else
 	{
-		gtk_container_focus (GTK_CONTAINER (embed->mozEmbed),
-				     GTK_DIR_TAB_FORWARD);
-		gtk_container_focus (GTK_CONTAINER (embed->mozEmbed),
-				     GTK_DIR_TAB_FORWARD);
+		if (GTK_BIN(embed->mozEmbed)->child)
+			gtk_widget_grab_focus (GTK_BIN(embed->mozEmbed)->child);
 		/* load the url */
 		gtk_moz_embed_load_url (embed->mozEmbed, url);
 	}
@@ -397,6 +395,9 @@ embed_create (GaleonEmbed *previous, gboolean new_window)
 	/* add to global list of all embeds */
 	all_embeds = g_list_append (all_embeds, embed);
 
+	/* not closing */
+	embed->is_closing = FALSE;
+
 	/* set magic */
 	embed->magic = GALEON_EMBED_MAGIC;
 
@@ -448,35 +449,27 @@ embed_progress_clear(GaleonEmbed *embed)
 /**
  * embed_show_find_dialog: show the find dialog
  */
-void embed_show_find_dialog (GaleonEmbed *embed, gpointer target)
+void embed_show_find_dialog (GaleonEmbed *embed)
 {
-	static GtkWidget *dFind = NULL;
 	GladeXML *gxml;
-
-	if (GTK_IS_WIDGET(dFind))
-	{
-		gdk_window_raise(dFind->window);
-		return;
-	}
+	
+	if (embed->find_dialog) return;
 
 	gxml = glade_xml_new (glade_file (), "dFind");
 	glade_xml_signal_autoconnect_full (gxml, glade_signal_connect_func,
 					   embed);
-	dFind = glade_xml_get_widget (gxml, "dFind");
 
-	/* if the dialog has a target show it as modal. 
-	 * Opening a new page would segfault. */
-	if (target)
-	{
-		gtk_window_set_modal (GTK_WINDOW (dFind), TRUE);
-	}
+	embed->find_dialog = g_new0 (FindDialog, 1);
+	embed->find_dialog->dialog = glade_xml_get_widget (gxml, "dFind");
+	embed->find_dialog->gnome_entry = glade_xml_get_widget (gxml, "find_gnome_entry");
+	embed->find_dialog->entry = glade_xml_get_widget (gxml, "find_entry");
+	embed->find_dialog->prev_button = glade_xml_get_widget (gxml, "BPrev");
+	embed->find_dialog->next_button = glade_xml_get_widget (gxml, "BNext");
+	embed->find_dialog->case_checkbutton = glade_xml_get_widget (gxml, "case_check");
+	embed->find_dialog->string_changed = TRUE;
 
-	gtk_object_set_data (GTK_OBJECT(dFind), "target", target);
-
-	gtk_widget_show(dFind);
-	window_set_layer(dFind);
-
-	embed->start_find = TRUE;
+	gtk_widget_show(embed->find_dialog->dialog);
+	window_set_layer(embed->find_dialog->dialog);
 }
 
 /**
@@ -534,14 +527,9 @@ void embed_add_temporary_bookmark (GaleonEmbed *embed)
  */
 void embed_show_save_dialog (GaleonEmbed *embed, gpointer target)
 {
-	static GtkWidget *fs = NULL;
+	GtkWidget *fs = NULL;
 	GladeXML *gxml;
-
-	if (GTK_IS_WIDGET(fs))
-	{
-		gdk_window_raise(fs->window);
-		return;
-	}
+	gchar *url, *filename;
 
 	gxml = glade_xml_new (glade_file (), "fssave");
 	glade_xml_signal_autoconnect_full (gxml, glade_signal_connect_func, 
@@ -549,12 +537,20 @@ void embed_show_save_dialog (GaleonEmbed *embed, gpointer target)
 
 	fs = glade_xml_get_widget(gxml, "fssave");
 
-	gtk_file_selection_set_filename 
-		(GTK_FILE_SELECTION (fs),
-		 gnome_config_get_string (CONF_DIR_SAVE));
+	if (target)
+		url = g_strdup(mozilla_get_eventtarget_url (embed, target));
+	else
+		url = gtk_moz_embed_get_location (embed->mozEmbed);
+
+	filename = embed_get_save_file_name (url);
+	gtk_file_selection_set_filename (GTK_FILE_SELECTION (fs), filename);
+
+	g_free(url);
+	g_free (filename);
 
 	gtk_object_set_data (GTK_OBJECT(fs), "target", target);
-	
+
+	gtk_window_set_modal(GTK_WINDOW(fs), TRUE);
 	gtk_widget_show(fs);
 	window_set_layer(fs);
 }
@@ -659,9 +655,19 @@ embed_view_source_external (GaleonEmbed *embed, gpointer target)
 void
 embed_close (GaleonEmbed *embed)
 {
+	/* already closing */
+	if (embed->is_closing)
+	{
+		return;
+	}
+	embed->is_closing = TRUE;
+
 	/* stop any loading */
 	gtk_moz_embed_stop_load (embed->mozEmbed);
 
+	/* set as invisible */
+	embed_set_visibility (embed, FALSE);
+
 	/* destroy the embedding widget -- this will also destroy 
 	 * the notebook tab and it's label, and remove it from 
 	 * the relevant lists */
@@ -713,7 +719,9 @@ embed_open_frame (GaleonEmbed *embed, gpointer target, gboolean same_embed,
 void
 embed_reload (GaleonEmbed *embed)
 {
-	if (strcmp (gtk_moz_embed_get_location (embed->mozEmbed),
+	GtkWidget *toolbar_entry = embed->parent_window->toolbar_entry;
+
+	if (strcmp (gtk_entry_get_text(GTK_ENTRY(toolbar_entry)),
 		    MYPORTAL_URL) == 0)
 	{
 		gtk_moz_embed_stop_load (embed->mozEmbed);
@@ -1003,3 +1011,50 @@ embed_set_page_location (GaleonEmbed *embed, const gchar *new_location)
 	window_update_nav_buttons (window);
 }
 
+
+/**
+ * embed_get_save_file_name: Parse a URL to find a filename for saving
+ *
+ * The string passed in will be modified. The returned string should be freed.
+ */
+static gchar *
+embed_get_save_file_name (gchar *url)
+{
+	gchar *filename, *curr;
+	gchar *default_name;
+
+	default_name = g_strdup_printf(_("index.html"));
+
+	if (!url)
+		return default_name;
+
+	filename = strrchr (url, '/');
+
+	if (!filename)
+		return default_name;
+	else if (filename && (*(filename + 1) == '\0'))
+		return default_name;
+	else
+	{
+		curr = ++filename;
+		while (*curr != '\0')
+		{
+			if (*curr == '?' || *curr == '#')
+			{
+				*curr = '\0';
+				break;
+			}
+			curr++;
+		}
+	}
+		
+	if (*filename == '\0')
+		return default_name;
+	else
+	{
+		g_free (default_name);
+
+		filename = g_strdup (filename);
+		return filename;
+	}
+}
