@@ -93,9 +93,16 @@ embed_notebook_switch_page_cb (GtkNotebook *notebook,
 	/* get the zoom value for the active page and set the spinbutton */
 	if (embed->wrapper)
 	{
-		mozilla_get_zoom(embed, &zoom);
-		gtk_spin_button_set_value(window->zoom_spin, zoom*100);
+		if (mozilla_get_zoom (embed, &zoom))
+		{
+			gtk_spin_button_set_value 
+				(GTK_SPIN_BUTTON (window->zoom_spin), zoom * 100);
+		}
 	}
+
+	/* Give the keyboard focus to the current page */
+	if (GTK_BIN(mozEmbed)->child)
+		gtk_widget_grab_focus(GTK_BIN(mozEmbed)->child);
 }
 
 /**
