@@ -25,6 +25,8 @@
 #include "nsIDocShellTreeItem.h"
 #include "nsIDocShellTreeOwner.h"
 #include "nsIDiskDocument.h"
+#include "nsIWebBrowserFind.h"
+#include "nsIWebBrowserFocus.h"
 #include "nsIDocument.h"
 #include "nsFileSpec.h"
 #include "nsISHEntry.h"
@@ -36,14 +38,13 @@
 #include "nsIDOMHTMLElement.h"
 #include "nsIDOMNamedNodeMap.h"
 #include "nsIDOMEventReceiver.h"
-#include "nsIFocusController.h"
 #include "nsIScriptGlobalObject.h"
-#include "nsPIDOMWindow.h"
 #include "nsIDOMWindowInternal.h"
 #include "nsIDOMHTMLAnchorElement.h"
 #include "nsIContentViewerFile.h"
 #include "nsICharsetConverterManager.h"
 #include "nsICharsetConverterManager2.h"
+#include "nsIInterfaceRequestor.h"
 
 #include "galeon-wrapper.h"
 
@@ -358,167 +359,17 @@ nsresult GaleonWrapper::GetSHTitleAtIndex (PRInt32 index, PRUnichar **title)
 	if (!NS_SUCCEEDED(result) || (!title)) return NS_ERROR_FAILURE;
 }
 
-nsresult GaleonWrapper::GetFocusedDOMWindow (nsIDOMWindowInternal **DOMWindow)
+nsresult GaleonWrapper::Find (const char *exp, PRBool matchcase, 
+			      PRBool search_backwards, PRBool* didFind)
 {
-	nsresult result;
+	nsCOMPtr<nsIWebBrowserFind> finder(do_GetInterface(mWebBrowser));
 
-	nsCOMPtr<nsIDocShell> DocShell;
-	result = GetDocShell (getter_AddRefs(DocShell));
-	if (NS_FAILED(result) || !DocShell) return NS_ERROR_FAILURE;
-
-	nsCOMPtr<nsIPresShell> PresShell;
-	result = DocShell->GetPresShell (getter_AddRefs(PresShell));
-	if (NS_FAILED(result) || !PresShell) return NS_ERROR_FAILURE;
-
-	nsCOMPtr<nsIDocument> Document;
-	result = PresShell->GetDocument (getter_AddRefs(Document));
-	if (NS_FAILED(result) || !Document) return NS_ERROR_FAILURE;
-
-	nsCOMPtr<nsIScriptGlobalObject> ourGlobal;
-	result = Document->GetScriptGlobalObject(getter_AddRefs(ourGlobal));
-	if (NS_FAILED(result) || !ourGlobal) return NS_ERROR_FAILURE;
-
-	nsCOMPtr<nsPIDOMWindow> ourWindow = do_QueryInterface(ourGlobal);
-	if (!ourWindow) return NS_ERROR_FAILURE;
-
-	nsCOMPtr<nsIFocusController> focusController;
-	result = ourWindow->GetRootFocusController
-					(getter_AddRefs(focusController));
-	if (NS_FAILED(result) || !focusController) return NS_ERROR_FAILURE;
-
-	return focusController->GetFocusedWindow(getter_AddRefs(DOMWindow));
-}
-
-nsresult GaleonWrapper::FindInMainDocument (const char *exp, PRBool matchcase, 
-			     PRBool search_backwards, PRBool start)
-{
-	nsresult result;
-
-	nsCOMPtr<nsIDOMWindowInternal> DOMWindow;
-	result = GetFocusedDOMWindow (getter_AddRefs(DOMWindow));
-	if (NS_FAILED(result) || !DOMWindow) return NS_ERROR_FAILURE;
-
-	nsCOMPtr<nsIDOMDocument> domDoc;
-	DOMWindow->GetDocument (getter_AddRefs(domDoc));
-	if (NS_FAILED(result) || !domDoc) return NS_ERROR_FAILURE;
-
-	return FindInDocument (domDoc, exp,matchcase, search_backwards, start);
-}
-
-nsresult GaleonWrapper::FindInDocument (nsIDOMDocument *aDOMDocument,
-					const char *exp,  PRBool matchcase, 
-					PRBool search_backwards, PRBool start)
-{
-	nsresult result;
-
-	/* create nsIServiceDocument */
-
-	nsCOMPtr<nsITextServicesDocument> textDoc;
-	result = nsComponentManager::CreateInstance(
-					kCTextServicesDocumentCID,
-					nsnull,
-					NS_GET_IID(nsITextServicesDocument),
-					getter_AddRefs(textDoc));
-	if (NS_FAILED(result) || !textDoc) return NS_ERROR_FAILURE;
-
-	nsCOMPtr<nsIDocument> doc = do_QueryInterface(aDOMDocument);
-	if(!doc) return NS_ERROR_FAILURE;
-
-	nsCOMPtr<nsIPresShell> presShell = getter_AddRefs(doc->GetShellAt(0));
-	if(!presShell) return NS_ERROR_FAILURE;
-
-	/* init nsIServiceDocument */
-
-	result = textDoc->InitWithDocument(aDOMDocument, presShell);
-	if (NS_FAILED(result)) return NS_ERROR_FAILURE;
-	
-	PRInt32 outBlockOffset = -1;
-
-	SetupFind(textDoc,&outBlockOffset,search_backwards,start);
-
-	PRBool atExtremum = PR_FALSE;     
-
-	regex_t preg;
-	regmatch_t match[1];
-	int res;
-	int eflags = 0;
-	
-	if (!matchcase) eflags = REG_ICASE;
-
-	regcomp(&preg,exp,eflags);
-
-	while ( NS_SUCCEEDED(textDoc->IsDone(&atExtremum)) && !atExtremum )
-	{
-		nsString str;
-		char *cstr, *tempcstr;
-
-		result = textDoc->GetCurrentTextBlock(&str);
-		if (NS_FAILED(result)) return result;
-		cstr = str.ToNewCString();
-		tempcstr = cstr;
-
-		match[0].rm_so = -1;
-		match[0].rm_eo = -1;
-
-		if (!search_backwards)
-		{
-			PRInt32 offset = 0;
-			if (outBlockOffset!=-1) offset = outBlockOffset;
-			res = regexec(&preg,tempcstr+offset,1,match,0);
-
-			if (res==0) {
-
-				textDoc->SetSelection(match[0].rm_so+offset,
-						match[0].rm_eo-match[0].rm_so);
-				textDoc->ScrollSelectionIntoView();
-				regfree(&preg);
-				return NS_OK;
-			}
-
-		}
-		else
-		{
-			gboolean not_found = TRUE;
-			PRInt32 eo = 0;
-			PRInt32 old_rm_eo = 0;
-			if (outBlockOffset!=-1) cstr[outBlockOffset] = 0;
-			while ((res = regexec(&preg,tempcstr,1,match,0))==0)
-			{
-				eo += old_rm_eo;
-				old_rm_eo = match[0].rm_eo;
-				tempcstr += match[0].rm_eo;
-				not_found = FALSE;
-			}
-			
-			if (!not_found) {
-
-				textDoc->SetSelection(match[0].rm_so+eo,
-						match[0].rm_eo-match[0].rm_so);
-				textDoc->ScrollSelectionIntoView();
-				regfree(&preg);
-				return NS_OK;
-			}
-		}
-
-		g_free(cstr);
-
-
-		if (!search_backwards)
-		{
-			result = textDoc->NextBlock(); 
-		}
-		else
-		{
-			result = textDoc->PrevBlock();
-		}
-
-		if (NS_FAILED(result)) return NS_ERROR_FAILURE;
-
-		outBlockOffset = -1;
-	}
-
-	regfree(&preg);
-	return NS_ERROR_FAILURE;
+	nsString searchString;
+	searchString.AssignWithConversion(exp);  
+	finder->SetSearchString(searchString.GetUnicode());
+	finder->SetFindBackwards(search_backwards);
+	finder->SetMatchCase(matchcase);
+	return finder->FindNext(didFind);
 }
 
 nsresult GaleonWrapper::ReloadDocument (nsIDOMDocument *aDOMDocument)
@@ -550,44 +401,6 @@ nsresult GaleonWrapper::ReloadDocument (nsIDOMDocument *aDOMDocument)
 	if (!NS_SUCCEEDED (result)) return NS_ERROR_FAILURE;
 }
 
-nsresult GaleonWrapper::SetupFind (nsITextServicesDocument *aDoc,
-				   PRInt32 *outBlockOffset,
-				   PRBool search_backwards, PRBool start)
-{
-	nsresult rv;
-	nsITextServicesDocument::TSDBlockSelectionStatus blockStatus;
-	PRInt32 selOffset;
-	PRInt32 selLength;
-
-	rv = aDoc->LastSelectedBlock(&blockStatus, &selOffset, &selLength);
-
-	if (!search_backwards)
-	{
-		if (NS_SUCCEEDED(rv) && (!start))
-		{
-			*outBlockOffset = selOffset+selLength;
-		}
-		else 
-		{
-			rv = aDoc->FirstBlock();
-		}
-	}
-	else
-	{
-		if (NS_SUCCEEDED(rv) && (!start))
-		{
-			*outBlockOffset = selOffset;
-		}
-		else 
-		{
-			rv = aDoc->LastBlock();
-		}
-	
-	}
-
-	return NS_OK; /* FIXME? */
-}
-
 nsresult GaleonWrapper::GetDocumentUrl (nsIDOMDocument *aDOMDocument, char **url)
 {
 	nsCOMPtr<nsIDocument> doc = do_QueryInterface(aDOMDocument);
@@ -809,6 +622,27 @@ nsresult GaleonWrapper::GetMouseEventContext (nsIDOMMouseEvent *event,
 
 }
 
+nsresult GaleonWrapper::ScrollbarClicked (nsIDOMMouseEvent *aMouseEvent)
+{
+	nsresult result;
+
+	nsCOMPtr<nsIDOMEventTarget> OriginalTarget;
+	result = aMouseEvent->GetOriginalTarget(getter_AddRefs(OriginalTarget));
+	if (NS_FAILED(result) || !OriginalTarget) return NS_ERROR_FAILURE;
+
+	nsCOMPtr<nsIDOMNode> node = do_QueryInterface(OriginalTarget);
+	if (!node) return NS_ERROR_FAILURE;
+
+	nsString nodename;
+	node->GetNodeName(nodename);
+
+	if (!strcmp(nodename.ToNewCString(), "xul:thumb") ||
+	    !strcmp(nodename.ToNewCString(), "xul:slider"))
+		return NS_OK;
+	else
+		return NS_ERROR_FAILURE;
+}
+
 nsresult  GaleonWrapper::CopyHistoryTo (GaleonWrapper *dest)
 {
 	nsresult result;
@@ -865,16 +699,21 @@ nsresult  GaleonWrapper::CopyHistoryTo (GaleonWrapper *dest)
 nsresult GaleonWrapper::SetSitePermission (gboolean block, PRInt32 type)
 {
 	nsresult result;
+	nsCOMPtr<nsIWebBrowserFocus> focus(do_GetInterface(mWebBrowser));
 
-	nsCOMPtr<nsIDOMWindowInternal> DOMWindow;
-	result = GetFocusedDOMWindow (getter_AddRefs(DOMWindow));
+	nsCOMPtr<nsIDOMWindow> DOMWindow;
+	result = focus->GetFocusedWindow (getter_AddRefs(DOMWindow));
 	if (NS_FAILED(result) || !DOMWindow) return NS_ERROR_FAILURE;
-	
+
+	nsCOMPtr<nsIDOMWindowInternal> DOMWindowInternal = do_QueryInterface (DOMWindow);
+	if (!DOMWindowInternal) return NS_ERROR_FAILURE;	
+
 	nsCOMPtr<nsICookieViewer> cookieviewer = do_CreateInstance
 							      (COOKIEVIEWER_ID);
-	result = cookieviewer->AddPermission(DOMWindow,
+	result = cookieviewer->AddPermission(DOMWindowInternal,
 					     block ? PR_TRUE : PR_FALSE, 
 					     type);
+	g_print ("aaaaa");
 	return result;
 }
 
