@@ -77,7 +77,6 @@ typedef struct GladeXML; /* urgh */
 #define CONF_GENERAL_LINKS_AUTOSHOW   "/galeon/General/links_autoshow=1"
 #define CONF_GENERAL_AUTOSHOW_TIME    "/galeon/General/autoshow_time=2"
 #define CONF_GENERAL_NEWWINDOWS       "/galeon/General/newwindows=0"
-#define CONF_GENERAL_TRUNCATE_MODE    "/galeon/General/truncate_mode=FALSE"
 
 #define CONF_COMPLETION_AUTOCOMP_ENABLE \
         "/galeon/completion/autocompletion=0"
@@ -97,16 +96,22 @@ typedef struct GladeXML; /* urgh */
                                       "/galeon/Appearance/tabbed_autojump=FALSE"
 #define CONF_APPEARANCE_TABBED_POSITION \
                                       "/galeon/Appearance/tabbed_position=2"
+#define CONF_APPEARANCE_TABBED_PREFIX "/galeon/Appearance/tabbed_prefix=TRUE"
+#define CONF_APPEARANCE_TABBED_SEPARATOR \
+	                              "/galeon/Appearance/tabbed_separator=TRUE"
+#define CONF_APPEARANCE_TABBED_VOWEL  "/galeon/Appearance/tabbed_vowel=FALSE"
 #define CONF_APPEARANCE_NAUTILUS_ICONS \
                                       "/galeon/Appearance/nautilus_icons=FALSE"
 #define CONF_APPEARANCE_TABBED_SHORTEN \
                                       "/galeon/Appearance/tabbed_shorten=30"
 #define CONF_MIME                     "/galeon/mime/"
-#define CONF_HANDLERS_MIME_ENABLE     "/galeon/handlers/mime_enable=TRUE"
+#define CONF_HANDLERS_MIME_ENABLE     "/galeon/handlers/mime_enable=FALSE"
 #define CONF_ADVANCED_IMAGE_LOADING_TYPE \
                                       "/galeon/Advanced/image_loading_type=0"
 #define CONF_ADVANCED_ANIMATE_TYPE    "/galeon/Advanced/animate_type=0"
 #define CONF_ADVANCED_HISTORY_EXPIRE  "/galeon/Advanced/history_expire=100"
+#define CONF_ADVANCED_STATUSBAR_REWRITE \
+	                              "/galeon/Advanced/statusbar_rewrite=TRUE"
 #define CONF_HANDLERS_USE_EXTERNAL_SOURCE_VIEWER \
                                        "/galeon/Handlers/use_external_source_viewer=FALSE"
 #define CONF_HANDLERS_EXTERNAL_SOURCE_VIEWER \
@@ -118,6 +123,7 @@ typedef struct GladeXML; /* urgh */
 #define CONF_ADVANCED_JAVASCRIPT_ENABLED \
                                        "/galeon/Advanced/javascript_enabled=1"
 #define CONF_ADVANCED_JAVA_ENABLED     "/galeon/Advanced/java_enabled=1" 
+#define CONF_ADVANCED_PROXY_ENABLED    "/galeon/Advanced/proxy_enabled=FALSE"
 #define CONF_AUTOBOOKMARKS_ENABLED     "/galeon/AutoBookmarks/enabled=TRUE" 
 #define CONF_AUTOBOOKMARKS_COUNT       "/galeon/AutoBookmarks/count=15" 
 #define CONF_AUTOBOOKMARKS_SHORTEN     "/galeon/AutoBookmarks/shorten=25" 
@@ -125,7 +131,6 @@ typedef struct GladeXML; /* urgh */
 #define CONF_ADVANCED_CRASH_BEHAVIOUR  "/galeon/Advanced/crash_behaviour=0"
 				       
 #define CONF_DIR_OPEN "/galeon/Directories/open=~/"
-#define CONF_DIR_SAVE "/galeon/Directories/save=~/"
 
 #define CONF_MOUSE_LINKS_DRAG "/galeon/Mouse/links_drag=FALSE"
 
@@ -134,7 +139,7 @@ typedef struct GladeXML; /* urgh */
 
 /* bookmark file locations - relative to home dir */
 #define NETSCAPE_BOOKMARKS "/.netscape/bookmarks.html"
-#define MOZILLA_BOOKMARKS "/.mozilla/default/bookmarks.html"
+#define MOZILLA_PREFS_DIR "/.mozilla/default/"
 				    
 /* Context menu types */
 
@@ -371,6 +376,25 @@ typedef enum {
 	LOADING
 } TabbedStatus;
 
+/* Destination for loading URLs */
+typedef enum {
+	NONE,
+	DEFAULT,
+	WINDOW,
+	TAB
+} ViewState;
+
+
+typedef struct {
+	GtkWidget *dialog;
+	GtkWidget *entry;
+	GtkWidget *gnome_entry;
+	GtkWidget *case_checkbutton;
+	GtkWidget *prev_button;
+	GtkWidget *next_button;
+	gboolean string_changed;
+} FindDialog;
+
 /* forward declarations of types */
 typedef struct _GaleonWindow GaleonWindow;
 typedef struct _GaleonEmbed GaleonEmbed;
@@ -429,6 +453,7 @@ struct _GaleonWindow
 	GtkWidget *use_own_colors;
 	GtkWidget *enable_java;
 	GtkWidget *enable_javascript;
+	GtkWidget *enable_proxy;
 	GtkWidget *use_galeon_mime_handling;
 
 	/* list of toolbars */
@@ -457,9 +482,6 @@ struct _GaleonEmbed
 	/* if TRUE this embed is in "view source" mode */
 	gboolean viewing_source;
 
-	/* if TRUE find must be restarted */
-	gboolean start_find;
-
 	/* is this browser actually visible */
 	gboolean is_visible;
 
@@ -468,6 +490,11 @@ struct _GaleonEmbed
 
 	/* ignore mime processing of next url */
 	gboolean mime_ignore_once;
+
+	/* is this embed closing? */
+	gboolean is_closing;
+
+	FindDialog *find_dialog;
 };
 
 #define GALEON_WINDOW_MAGIC   (0x87de130f)
@@ -665,7 +692,7 @@ void embed_load_url (GaleonEmbed *embed, const gchar *url);
 void embed_progress_clear (GaleonEmbed *embed);
 void embed_show_save_dialog(GaleonEmbed *embed, gpointer target);
 void embed_add_temporary_bookmark (GaleonEmbed *embed);
-void embed_show_find_dialog (GaleonEmbed *embed, gpointer target);
+void embed_show_find_dialog (GaleonEmbed *embed);
 void embed_edit_bookmarks (GaleonEmbed *embed);
 void embed_view_source (GaleonEmbed *embed, gpointer target, 
 			gboolean new_window);
@@ -681,6 +708,7 @@ void embed_set_notebook_label_status (GaleonEmbed *embed, TabbedStatus status);
 void embed_toggle_view_source_mode (GaleonEmbed *embed);
 
 /* window.c */
+GtkWidget *window_lookup_wmain (GtkWidget *widget);
 GaleonWindow *window_create (void);
 void window_set_fullscreen_mode (GaleonWindow *window, gboolean active);
 void window_show_open_dialog (GaleonWindow *window);
@@ -765,6 +793,10 @@ void mozembed_destroy_cb (GtkObject *object, GaleonEmbed *embed);
 void window_spinner_button_clicked_cb(GtkButton *button, GaleonWindow *window);
 void history_menu_menuitem_activate_cb (GtkMenuItem *menuitem, 
 					gpointer user_data);
+gboolean client_save_yourself_cb (GnomeClient *client, gint phase, 
+				  GnomeSaveStyle save_style, gint shutdown,
+				  GnomeInteractStyle interact_style,
+				  gint fast);
 
 /* history.c */
 void history_show_dialog (void);
@@ -855,6 +887,7 @@ gboolean netscape_import_prefs (void);
 /* prefs.c */
 void preferences_load (void);
 void preferences_save (void);
+void preferences_help (void);
 void preferences_set_dialog_to_config (GtkWidget *widget);
 void preferences_set_config_to_dialog (GtkWidget *widget);
 void preferences_apply (void);
@@ -862,6 +895,7 @@ void set_settings_menu_window (GaleonWindow *window);
 void preferences_set_use_provided_colors (gboolean value);
 void preferences_set_enable_javascript (gboolean value);
 void preferences_set_enable_java (gboolean value);
+void preferences_set_enable_proxy (gboolean value);
 void preferences_set_use_provided_fonts (gboolean value);
 void preferences_set_image_loading (ImageLoadingType value);
 void preferences_set_animate (AnimateType value);
@@ -901,8 +935,7 @@ extern gboolean mozilla_preference_set_int (const char *preference_name,
 extern gboolean mozilla_save (GaleonEmbed *b, const char *fname, 
 			      gpointer target);
 extern gboolean mozilla_find (GaleonEmbed *embed, const char *exp,
-			      gboolean matchcase, gboolean search_backwards,
-			      gboolean start, gpointer target);
+			      gboolean matchcase, gboolean search_backwards);
 extern gboolean mozilla_session_history (GaleonEmbed *embed, char **titles[],
 					 int *count, int *index);
 extern gboolean mozilla_copy_session_history (GaleonEmbed *embed, 
@@ -917,6 +950,7 @@ extern gboolean mozilla_scroll (GtkMozEmbed *b, gint lines, gint pages);
 extern gboolean mozilla_scroll_begin (GtkMozEmbed *b);
 extern gboolean mozilla_scroll_end (GtkMozEmbed *b);
 extern gint mozilla_get_mouse_button (gpointer event);
+extern gboolean mozilla_scrollbar_clicked (GaleonEmbed *embed, gpointer event);
 extern gint mozilla_get_event_context (GaleonEmbed *embed, gpointer event, 
 				       gchar **img, gpointer *target, 
 				       gchar **link);
@@ -1013,6 +1047,7 @@ void glade_signal_connect_func (const gchar *cb_name, GtkObject *obj,
 char *tmpnam_ex (char *suffix);
 void copy_to_clipboard (gchar *text, GaleonEmbed *embed);
 void galeon_quit (GaleonWindow *window);
+void galeon_quit_with_session (void);
 void galeon_exit (void);
 void remove_directory (const char *dirname, gboolean just_clean);
 gchar *shorten_name (const gchar *name, gint target_length);
@@ -1020,6 +1055,7 @@ void initialise_colours (void);
 gchar *read_line_from_file (FILE *f);
 void create_charset_submenus (GtkMenuItem *encoding_menu_item, 
 			GList *charset_titles, GaleonWindow *window);
+gchar* get_mozilla_prefs_directory (); 
 
 /* auto_completion.c */
 void auto_completion_add_url (gchar *url);
