@@ -64,6 +64,8 @@ void window_menu_own_colors_activate_cb (GtkCheckMenuItem *menuitem,
 					 GaleonWindow *window);
 void window_menu_enable_javascript_activate_cb (GtkCheckMenuItem *menuitem, 
 						GaleonWindow *window);
+void window_menu_enable_proxy_activate_cb (GtkCheckMenuItem *menuitem,
+                                                GaleonWindow *window);
 void window_menu_own_fonts_activate_cb (GtkCheckMenuItem *menuitem,
 					GaleonWindow *window);
 void window_menu_galeon_mime_handling_activate_cb (GtkCheckMenuItem *menuitem, 
@@ -206,7 +208,7 @@ window_menu_prefs_activate_cb (GtkMenuItem *menuitem, GaleonWindow *window)
 void 
 window_menu_bookmark_activate_cb (GtkMenuItem *menuitem, gpointer user_data) 
 {
-        GtkWidget *WMain = glade_lookup_widget (GTK_WIDGET (menuitem), "WMain");
+        GtkWidget *WMain = window_lookup_wmain(GTK_WIDGET (menuitem));
         GaleonWindow *window = (GaleonWindow*) gtk_object_get_data
 		(GTK_OBJECT (WMain), "GaleonWindow");
 	BookMarkItem *bm = (BookMarkItem *)user_data;
@@ -242,7 +244,7 @@ void
 window_menu_find_activate_cb (GtkMenuItem *menuitem, GaleonWindow *window)
 {
 	return_if_not_window (window);
-	embed_show_find_dialog (window->active_embed, NULL);
+	embed_show_find_dialog (window->active_embed);
 }
 
 /**
@@ -251,7 +253,7 @@ window_menu_find_activate_cb (GtkMenuItem *menuitem, GaleonWindow *window)
 void 
 window_menu_recent_activate_cb (GtkMenuItem *menuitem, gpointer user_data)
 {
-        GtkWidget *WMain = glade_lookup_widget (GTK_WIDGET (menuitem), "WMain");
+        GtkWidget *WMain = window_lookup_wmain (GTK_WIDGET (menuitem));
         GaleonWindow *window = (GaleonWindow *) gtk_object_get_data
 		(GTK_OBJECT (WMain), "GaleonWindow");
         history_item *hi = gtk_object_get_user_data (GTK_OBJECT (menuitem));
@@ -310,6 +312,7 @@ window_menu_about_activate_cb (GtkMenuItem *menuitem, GaleonWindow *window)
 		"Bob Phan <ex-freek@yahoo.com>",
 		"Matt Aubury <matt@ookypooky.com>",
 		"Joshua Horvath <jmhorvat@home.com>",
+		"Yanko Kaneti <yaneti@declera.com>",
 		"","Graphic arts :", "Toussaint Frederic (fred@linuxgraphic.org)",
 		NULL
 	};
@@ -414,23 +417,8 @@ void
 window_menu_exit_with_session_activate_cb (GtkMenuItem *menuitem, 
 					   GaleonWindow *window)
 {
-	gchar *filename;
-
 	return_if_not_window (window);
-
-	/* make the session filename string */
-	filename = g_strconcat (g_get_home_dir (),
-				"/.galeon/session_saved.xml", NULL);
-
-	/* save it out */
-	session_save(filename);
-
-	/* set config marker */
-	gnome_config_set_int ("/galeon/General/session_saved", 1);
-	gnome_config_sync ();
-
-	/* normal quit */
-	galeon_quit (window);
+	galeon_quit_with_session ();
 }
 
 /** 
@@ -439,19 +427,14 @@ window_menu_exit_with_session_activate_cb (GtkMenuItem *menuitem,
 void
 window_menu_print_activate_cb (GtkMenuItem *menuitem, GaleonWindow *window)
 {
-	static GtkWidget *dialog = NULL;
+	GtkWidget *dialog = NULL;
 
 	return_if_not_window (window);
 
-	if (GTK_IS_WIDGET(dialog))
-	{
-		gdk_window_raise(dialog->window);
-		return;
-	}
-
 	if (!mozilla_print (window->active_embed))
 	{
 		dialog = gnome_error_dialog ("Not yet implemented.");
+		gtk_window_set_modal (GTK_WINDOW(dialog), TRUE);
 		window_set_layer (dialog);
 	}
 }
@@ -645,6 +628,15 @@ window_menu_enable_javascript_activate_cb (GtkCheckMenuItem *menuitem,
 	preferences_set_enable_javascript (menuitem->active);
 }
 
+void
+window_menu_enable_proxy_activate_cb (GtkCheckMenuItem *menuitem,
+                                           GaleonWindow *window)
+{
+        return_if_not_window (window);
+        preferences_set_enable_proxy (menuitem->active);
+}
+
+
 void
 window_menu_own_fonts_activate_cb (GtkCheckMenuItem *menuitem,
 				   GaleonWindow *window)
