@@ -82,6 +82,7 @@ static void add_bf_menu (GtkWidget *menu, char* label, int index,
 static void free_string_array (char *array[], int size);
 static void unrecognised_protocol_cb(gint reply, gpointer url);
 inline gchar * glade_file(void);
+static gboolean is_punctuation (gchar c);
 
 /**
  * glade_lookup_widget
@@ -731,10 +732,23 @@ copy_to_clipboard (gchar *text, GaleonEmbed *embed)
 	}
 } 
 
-void galeon_quit (GaleonWindow *window)
+static void
+galeon_close_all_windows (void)
 {
 	GList *wl, *next;
 
+	/* close all windows: this in turn will close all embeds */
+	/* at the closing of the last window galeon_exit will be called */
+	for (wl = all_windows; wl != NULL;)
+	{
+		next = wl->next;
+		window_close ((GaleonWindow *)(wl->data));
+		wl = next;
+	}
+}
+
+void galeon_quit (GaleonWindow *window)
+{
 	/* location bar history is saved automatically when the widget is
 	   destroyed. we don't want to save the text currently in the entry */
 	gtk_editable_delete_text (GTK_EDITABLE (window->toolbar_entry),
@@ -750,14 +764,29 @@ void galeon_quit (GaleonWindow *window)
 				     window->WMain->allocation.height);
 	}
 
-	/* close all windows: this in turn will close all embeds */
-	/* at the closing of the last window galeon_exit will be called */
-	for (wl = all_windows; wl != NULL;)
-	{
-		next = wl->next;
-		window_close ((GaleonWindow *)(wl->data));
-		wl = next;
-	}
+	/* close all windows, this will also quit */
+	galeon_close_all_windows ();
+}
+
+void
+galeon_quit_with_session (void)
+{
+	gchar *filename;
+
+	/* make the session filename string */
+	filename = g_strconcat (g_get_home_dir (),
+				"/.galeon/session_saved.xml", NULL);
+
+	/* save it out */
+	session_save(filename);
+
+	/* set config marker */
+	gnome_config_set_int ("/galeon/General/session_saved", 1);
+	gnome_config_sync ();
+
+	/* close all windows and exit */
+	galeon_close_all_windows ();
+
 }
 
 void galeon_exit (void)
@@ -808,6 +837,13 @@ remove_directory(const char *dirname, gboolean just_clean)
         g_free(oldcwd);
 }
 
+static gboolean
+is_punctuation (gchar c)
+{
+	return (c == ' ' || c == '.' || c == '!' || c == '|' ||
+		c == ',' || c == ':' || c == ';');
+}
+
 /**
  * shorten_name: try to shorten a page title (ideally to target_length or 
  * less). The heurstics here seems to give pretty good results even down
@@ -818,135 +854,177 @@ gchar *
 shorten_name(const gchar *input_name, gint target_length)
 {
 	gint i, j, length;
-	gboolean found_other;
-	gchar *dup_name, *name;
+	gchar *name;
 	char c;
 
-	/* copy and clean name -- could be improved */
-	dup_name = g_strdup (input_name);
-	name = g_strdup (g_strstrip (dup_name));
-	g_free (dup_name);
-
-	/* already short enough? */
-	length = strlen (name);
-	if (length <= target_length)
-	{
-		return name;
-	}
-
-	/* find some separating punctuation */
-	found_other = FALSE;
-	for (i = 0; i < length; i++)
-	{
-		c = name[i];
-		if (found_other && 
-		    (c == '/' || c == '!' || c == ':' || c == ';' || 
-		     c == ',' || c == '-' || c == '|' || c == '.'))
-		{
-			/* stop here */
-			break;			
-		}
-		else
-		{
-			found_other = TRUE;
-		}
-	}
-
-	/* copy (possibly) shortend string */
-	name[i] = '\0';
-	g_strchomp (name);
+	/* copy and clean name */
+	name = g_strdup (input_name);
+	g_strstrip (name);
 	length = strlen (name);
 
-	/* short enough yet? */
-	if (length <= target_length)
+	/* take care of stupid web pages that have a single non-breaking
+	 * space in their titles (yes, i've seen this done) */
+	if (length == 0)
 	{
-		return name;
+		free (name);
+		return (g_strdup ("Untitled"));
 	}
 
 	/* look for some common prefixes -- should these be translated? */
-	if (strncasecmp (name, "the ", 4) == 0)
+	if (gnome_config_get_bool (CONF_APPEARANCE_TABBED_PREFIX))
 	{
-		length -= 4;
-		memmove(name, name + 4, length + 1);
-	}
-	else if (strncasecmp (name, "welcome to ", 11) == 0)
-	{
-		length -= 11;
-		memmove(name, name + 11, length + 1);
-	}
-	else if (strncasecmp (name, "index of ", 9) == 0)
-	{
-		length -= 9;
-		memmove(name, name + 9, length + 1);
-	}
-
-	/* which mode are we in? */
-	if (gnome_config_get_bool (CONF_GENERAL_TRUNCATE_MODE))
-	{
-		/* truncate mode: just chop off and add ellipsis */
-		for (i = 0; i < 3; i++)
+		/* prefixes that only come by themselves */
+		if (strncasecmp (name, "index of ", 9) == 0)
 		{
-			/* don't overflow string length */
-			if (name[target_length + i] == '\0')
-				break;
-			
-			name[target_length + i] = '.';
+			length -= 9;
+			memmove(name, name + 9, length + 1);
+		}
+		else if (strncasecmp (name, "re: ", 4) == 0)
+		{
+			length -= 4;
+			memmove(name, name + 4, length + 1);
+		}
+		else if (strncasecmp (name, "fwd: ", 5) == 0)
+		{
+			length -= 5;
+			memmove(name, name + 5, length + 1);
+		}
+		{
+			/* prefixes that can be followed by other
+			 * prefixes */
+			if (strncasecmp (name, "welcome to ", 11) == 0)
+			{
+				length -= 11;
+				memmove(name, name + 11, length + 1);
+			}
+
+			/* prefixes that follow the ones in the
+			 * previous group */
+			if (strncasecmp (name, "a ", 2) == 0)
+			{
+				length -= 2;
+				memmove(name, name + 2, length + 1);
+			}
+			else if (strncasecmp (name, "my ", 3) == 0)
+			{
+				length -= 3;
+				memmove(name, name + 3, length + 1);
+			}
+			else if (strncasecmp (name, "the ", 4) == 0)
+			{
+				length -= 4;
+				memmove(name, name + 4, length + 1);
+			}
 		}
 
-		/* terminate string */
-		name[target_length + i] = '\0';
+		/* remove any leading whitespace */
+		g_strchug (name);
+	}
 
-		/* return it */
+	/* check length */
+	length = strlen (name);
+	if (length <= target_length)
+	{
 		return name;
 	}
 
+	/* find in name the first occurence of one of
+	 * several common separators, and set it to '\0' */
+	if (gnome_config_get_bool (CONF_APPEARANCE_TABBED_SEPARATOR))
+	{
+		gchar *first;
+		gchar *str;
+
+		/* set first to initially point to the terminating '\0'
+		 * character */
+		first = name + sizeof (gchar) * strlen (name);
+
+		/* search for various separators... we can now search
+		 * for ": ", becuase because we have stripped "re:" and
+		 * "fwd: " in an earlier test */
+		str = strstr (name, " - ");
+		if (str != NULL && str < first) first = str;
+		str = strstr (name, " -- ");
+		if (str != NULL && str < first) first = str;
+		str = strstr (name, " | ");
+		if (str != NULL && str < first) first = str;
+		str = strstr (name, " || ");
+		if (str != NULL && str < first) first = str;
+		str = strstr (name, ": ");
+		if (str != NULL && str < first) first = str;
+		str = strstr (name, " :: ");
+		if (str != NULL && str < first) first = str;
+
+		*first = '\0';
+
+		/* check length */
+		g_strchomp (name);
+		length = strlen (name);
+		if (length <= target_length)
+		{
+			return name;
+		}
+	}
+
 	/* getting tricky, try losing a few vowels */
 	/* yes, this is very anglocentric -- I don't know of any strategies
 	 * for other languages (particularly non-European) -- MattA */
-	for (i = length - 1, j = length - 1; i >= 0; i--)
+	if (gnome_config_get_bool (CONF_APPEARANCE_TABBED_VOWEL))
 	{
-		c = name[i];
-		if (length <= target_length ||
-		    (c != 'a' && c != 'e' && c != 'i' && c != 'o' && c != 'u'))
+		for (i = length - 1, j = length - 1; i >= 0; i--)
 		{
-			name[j--] = c;
+			c = name[i];
+			if (length <= target_length ||
+			    (c != 'a' && c != 'e' && c != 'i' &&
+			     c != 'o' && c != 'u'))
+			{
+				name[j--] = c;
+			}
+			else
+			{
+				length--;
+			}
 		}
-		else
-		{
-			length--;
-		}
-	}
-	/* shift */
-	memmove(name, name + j + 1, length + 1);
+		/* shift */
+		memmove(name, name + j + 1, length + 1);
 
-	/* short enough yet? */
-	if (length <= target_length)
-	{
-		return name;
+		/* short enough yet? */
+		if (length <= target_length)
+		{
+			return name;
+		}
 	}
 
 	/* argh -- try chopping out whole words */
 	for (i = target_length; i > 0; i--)
 	{
-		if (name[i] == ' ')
+		if (is_punctuation (name[i]))
 		{
+			while (is_punctuation (name[i]))
+			{
+				i--;
+			}
 			/* this will do */
-			name[i] = '\0';
+			name[i + 1] = '\0';
+			g_strchomp (name);
 			return name;
 		}
 	}
 
-	/* right, just take the first word, it's the best we can do */
-	for (i = 0; i < length; i++)
+	/* just chop off and add ellipsis */
+	for (i = 0; i < 3; i++)
 	{
-		if (name[i] == ' ')
-		{
-			name[i] = '\0';
-			return name;
-		}
+		/* don't overflow string length */
+		if (name[target_length + i] == '\0')
+			break;
+		
+		name[target_length + i] = '.';
 	}
-
-	/* one long word... */
+	
+	/* terminate string */
+	name[target_length + i] = '\0';
+	
+	/* return it */
 	return name;
 }
 
@@ -1074,3 +1152,37 @@ create_charset_submenus (GtkMenuItem *encoding_menu_item, GList *charset_titles,
 		templ = g_list_remove_link (templ, templ);
 	}
 }
+
+gchar* get_mozilla_prefs_directory () 
+{
+	GnomeVFSResult rc;
+	GList *list = NULL;
+	GList *node;
+	GnomeVFSFileInfo *info;
+	char *prefs_dir = NULL;
+	char *default_dir;
+
+	default_dir = g_strconcat (g_get_home_dir(), MOZILLA_PREFS_DIR, NULL);
+	
+	rc = gnome_vfs_directory_list_load(&list,
+					   default_dir,
+					   (GNOME_VFS_FILE_INFO_GET_MIME_TYPE
+					    | GNOME_VFS_FILE_INFO_FORCE_FAST_MIME_TYPE
+					    | GNOME_VFS_FILE_INFO_FOLLOW_LINKS),
+					   NULL);
+
+	for (node = list; node; node = node->next) {
+		info = node->data;
+
+		if (info->type == GNOME_VFS_FILE_TYPE_DIRECTORY)
+		{
+			prefs_dir = g_strconcat(default_dir, info->name, NULL);
+			continue;
+		}
+	}
+
+	gnome_vfs_file_info_list_free(list);
+	g_free (default_dir);
+
+	return prefs_dir;
+}
