@@ -73,7 +73,8 @@ mozembed_new_window_cb (GtkMozEmbed *dummy, GtkMozEmbed **retval,
 }
 
 /**
- * mozembed_visibility_cb: GTKMOZEMBED SIGNAL, emitted when the toplevel window need to be showed or hidden
+ * mozembed_visibility_cb: GTKMOZEMBED SIGNAL, emitted when the toplevel
+ * window need to be showed or hidden
  */
 void 
 mozembed_visibility_cb (GtkMozEmbed *dummy, gboolean visibility, 
@@ -83,11 +84,8 @@ mozembed_visibility_cb (GtkMozEmbed *dummy, gboolean visibility,
 
 	return_if_not_embed (embed);
 
-	/* show or hide browser toplevel window */
-	if (embed->is_active)
-	{
-		embed_set_visibility (embed, visibility);
-	}
+	/* set visiblity of this embed */
+	embed_set_visibility (embed, visibility);
 
 	/* do embed init if necessary */
 	if (visibility && !embed->wrapper)
@@ -170,16 +168,15 @@ mozembed_load_started_cb (GtkMozEmbed *dummy, GaleonEmbed *embed)
 	window = embed->parent_window;
 	return_if_not_window (window);
 
-	/* start the window spinner */
+	/* if we haven't already, start the window spinner, set the
+	 * load_started tag, and clear the info about the progress */
 	if (!(embed->load_started))
 	{
 		spinner_start (window);
+		embed->load_started = TRUE;
+		embed_progress_clear (embed);
 	}
 
-	/* set in the embed */
-	embed->load_started = TRUE;
-	embed_progress_clear (embed);
-
 	/* update the buttons view */
 	if (embed == window->active_embed)
 	{
@@ -379,14 +376,17 @@ mozembed_js_status_cb (GtkMozEmbed *dummy, GaleonEmbed *embed)
 	window = embed->parent_window;
 	return_if_not_window (window);
 
-	/* get the javascript message */
-	message = gtk_moz_embed_get_js_status (embed->mozEmbed);
-
-	/* update the status bar message */
-	if (message)
-	{
-		window_update_temp_message (window, message);
-		g_free (message);
+ 	if (gnome_config_get_bool (CONF_ADVANCED_STATUSBAR_REWRITE))
+  	{
+		/* get the javascript message */
+		message = gtk_moz_embed_get_js_status (embed->mozEmbed);
+		
+		/* update the status bar message */
+		if (message && embed->is_active)
+		{
+			window_update_temp_message (window, message);
+			g_free (message);
+		}
 	}
 }
 
@@ -429,6 +429,10 @@ mozembed_dom_mouse_click_cb (GtkMozEmbed *dummy, gpointer dom_event,
 	window = embed->parent_window;
 	return_val_if_not_window (window, FALSE);
 
+	/* Do not process the event if it occurred on a scrollbar */
+	if (mozilla_scrollbar_clicked(embed, dom_event))
+		return FALSE;
+
 	tabbed_mode = gnome_config_get_bool (CONF_APPEARANCE_TABBED);
 	type = mozilla_get_event_context (embed, dom_event,
 					  &img, &target, &href);
@@ -502,7 +506,7 @@ mozembed_dom_mouse_click_cb (GtkMozEmbed *dummy, gpointer dom_event,
 }
 
 /**
- * mozembed_dom_mouse_click_cb: GTKMOZEMBED SIGNAL, emitted when a key is 
+ * mozembed_dom_key_press_cb: GTKMOZEMBED SIGNAL, emitted when a key is 
  * pressed
  */
 gint mozembed_dom_key_press_cb (GtkMozEmbed *dummy, gpointer dom_event, 
@@ -511,6 +515,7 @@ gint mozembed_dom_key_press_cb (GtkMozEmbed *dummy, gpointer dom_event,
 	GaleonWindow *window;
 	int modifier, state = 0;
 	long key;
+	gboolean handled;
 
 	return_val_if_not_embed (embed, FALSE);
 	window = embed->parent_window;
@@ -535,8 +540,6 @@ gint mozembed_dom_key_press_cb (GtkMozEmbed *dummy, gpointer dom_event,
 	}
 	else if ((modifier & ALT_KEY) && (modifier & CTRL_KEY))
 	{
-		state = GDK_MOD1_MASK | GDK_CONTROL_MASK;
-
 		switch(key)
 		{
 		default:
@@ -574,8 +577,6 @@ gint mozembed_dom_key_press_cb (GtkMozEmbed *dummy, gpointer dom_event,
 	}
 	else if ((modifier & ALT_KEY) && !(modifier & (CTRL_KEY | SHIFT_KEY)))
 	{
-		state = GDK_MOD1_MASK;
-
 		switch(key)
 		{
 		case DOM_VK_1:
@@ -605,30 +606,8 @@ gint mozembed_dom_key_press_cb (GtkMozEmbed *dummy, gpointer dom_event,
 
 		}
 	}
-	else if (modifier & KEY_CODE)
-	{
-		switch(key)
-		{
-		case DOM_VK_ESCAPE:
-			key = GDK_Escape;
-			break;
-		case DOM_VK_F11:
-			key = GDK_F11;
-			break;
-		case DOM_VK_F6:
-			key = GDK_F6;
-			break;
-		case DOM_VK_F3:
-			key = GDK_F3;
-			break;
-		default:
-			break;
-		}
-	}
 	else if (modifier & CTRL_KEY)
 	{		
-		state = GDK_CONTROL_MASK;
-
 		switch(key)
 		{
 		case DOM_VK_g:
@@ -640,7 +619,9 @@ gint mozembed_dom_key_press_cb (GtkMozEmbed *dummy, gpointer dom_event,
 			return TRUE;
 			break;   
 		case DOM_VK_EQUALS:
-			gtk_spin_button_spin (GTK_SPIN_BUTTON (window->zoom_spin), GTK_SPIN_STEP_FORWARD, 10);
+			gtk_spin_button_spin
+					(GTK_SPIN_BUTTON(window->zoom_spin),
+					 GTK_SPIN_STEP_FORWARD, 10);
 			return TRUE;
 			break;
 		default:
@@ -649,15 +630,93 @@ gint mozembed_dom_key_press_cb (GtkMozEmbed *dummy, gpointer dom_event,
 		}
 	}
 
+	if (modifier & KEY_CODE)
+	{
+		/* The extended keys have different keycodes in Mozilla/GDK,
+		   so we need to translate them here */
+		switch(key)
+		{
+		case DOM_VK_PAGE_UP:
+			key = GDK_Page_Up;
+			break;
+		case DOM_VK_PAGE_DOWN:
+			key = GDK_Page_Down;
+			break;
+		case DOM_VK_HOME:
+			key = GDK_Home;
+			break;
+		case DOM_VK_END:
+			key = GDK_End;
+			break;
+		case DOM_VK_INSERT:
+			key = GDK_Insert;
+			break;
+		case DOM_VK_ESCAPE:
+			key = GDK_Escape;
+			break;
+		case DOM_VK_F12:
+			key = GDK_F12;
+			break;
+		case DOM_VK_F11:
+			key = GDK_F11;
+			break;
+		case DOM_VK_F10:
+			key = GDK_F10;
+			break;
+		case DOM_VK_F9:
+			key = GDK_F9;
+			break;
+		case DOM_VK_F8:
+			key = GDK_F8;
+			break;
+		case DOM_VK_F7:
+			key = GDK_F7;
+			break;
+		case DOM_VK_F6:
+			key = GDK_F6;
+			break;
+		case DOM_VK_F5:
+			key = GDK_F5;
+			break;
+		case DOM_VK_F4:
+			key = GDK_F4;
+			break;
+		case DOM_VK_F3:
+			key = GDK_F3;
+			break;
+		case DOM_VK_F2:
+			key = GDK_F2;
+			break;
+		case DOM_VK_F1:
+			key = GDK_F1;
+			break;
+		default:
+			break;
+		}
+	}
+
+	if (modifier & CTRL_KEY)
+		state |= GDK_CONTROL_MASK;
+	if (modifier & SHIFT_KEY)
+		state |= GDK_SHIFT_MASK;
+	if (modifier & ALT_KEY)
+		state |= GDK_MOD1_MASK;
+
 	/* We haven't specifically handled the keypress, so send it to the
 	   main window in case it is a menu accelerator key */
-	gtk_accel_groups_activate (GTK_OBJECT (window->WMain), key, state);
+	handled = gtk_accel_groups_activate (GTK_OBJECT (window->WMain),
+					     key, state);
 
-	return FALSE;
+	/* If it wasn't an accelerator, let Mozilla handle it */
+	if (!handled)
+		return FALSE;
+
+	return TRUE;
 }
 
 /**
- * mozembed_dom_mouse_click_cb: GTKMOZEMBED SIGNAL, emitted when a size change is requested
+ * mozembed_size_to_cb: GTKMOZEMBED SIGNAL, emitted when a  size change 
+ * is requested
  */
 void 
 mozembed_size_to_cb (GtkMozEmbed *dummy, gint width, gint height,
@@ -672,7 +731,8 @@ mozembed_size_to_cb (GtkMozEmbed *dummy, gint width, gint height,
 	/* hmm, FIXME..? */
 	if (embed->is_active)
 	{
-		gtk_widget_set_usize (window->WMain, width, height);
+		gtk_window_set_default_size (GTK_WINDOW (window->WMain), 
+					     width, height);
 	}
 }
 
