@@ -488,30 +488,21 @@ mozilla_session_history_go (GaleonEmbed *embed, int index)
 
 /**
  * mozilla_find: find a word in the document
- * @target: dom event target, used to save a page from a context menu.
- * When NULL, the focused page is saved
  */
 extern "C" gboolean
-mozilla_find (GaleonEmbed *embed,const char *exp,gboolean matchcase,gboolean search_backwards,gboolean start, gpointer target)
+mozilla_find (GaleonEmbed *embed,const char *exp,gboolean matchcase,gboolean search_backwards)
 {
-	nsresult result;
 	GaleonWrapper *wrapper;
+	PRBool didFind;
 
 	g_return_val_if_fail (embed != NULL, FALSE);
 	g_return_val_if_fail (embed->wrapper != NULL, FALSE); 
 
 	wrapper = (GaleonWrapper *)embed->wrapper;
 
-	if (target)
-	{
-		result = wrapper->FindInDocument ((nsIDOMDocument*)target, exp, matchcase, search_backwards, start);
-	}
-	else
-	{
-		result = wrapper->FindInMainDocument (exp, matchcase, search_backwards, start);
-	}
+	wrapper->Find (exp, matchcase, search_backwards, &didFind);
 
-	return NS_SUCCEEDED (result) ? TRUE : FALSE;
+	return didFind;
 }
 
 /**
@@ -596,6 +587,22 @@ mozilla_get_mouse_button (gpointer event)
 	return NS_SUCCEEDED (result) ? button : 0;
 }
 
+/**
+ * mozilla_scrollbar_clicked: check to see if a mouse click event occurred
+ *                            on a scrollbar
+ */
+extern "C" gboolean
+mozilla_scrollbar_clicked (GaleonEmbed *embed, gpointer event)
+{
+	nsresult result;
+	nsIDOMMouseEvent *aMouseEvent = ((nsIDOMMouseEvent *)event);
+	GaleonWrapper *wrapper = (GaleonWrapper *)embed->wrapper;
+
+	result = wrapper->ScrollbarClicked(aMouseEvent);
+
+	return NS_SUCCEEDED (result) ? TRUE : FALSE;
+}
+
 /**
  * mozilla_get_key_pressed: get pressed key button from a DOM key event
  */
