@@ -114,6 +114,7 @@ mozilla_prefs_set_java (void)
 	mozilla_preference_set_boolean ("javascript.enabled", javascript_enabled); 
 }
 
+
 /**
  * mozilla_prefs_set_network: set network preferences
  */
@@ -254,68 +255,75 @@ mozilla_prefs_set_colors (void)
 void 
 mozilla_prefs_set_proxy (void)
 {
+        gboolean proxy_enabled = gnome_config_get_bool (CONF_ADVANCED_PROXY_ENABLED);
+
 	gchar *http_proxy, *ssl_proxy, *ftp_proxy;
 	int http_proxy_port, ssl_proxy_port, ftp_proxy_port;
 	gchar *no_proxies_for;
 	gboolean proxy_keepalive;
 	
+	if (proxy_enabled) {
 
-	http_proxy = gnome_config_get_string ("/galeon/Advanced/http_proxy=");
-	http_proxy_port = gnome_config_get_int ("/galeon/Advanced/http_proxy_port=8080");
-	ssl_proxy = gnome_config_get_string("/galeon/Advanced/ssl_proxy=");
-	ssl_proxy_port = gnome_config_get_int("/galeon/Advanced/ssl_proxy_port=8080");
-	ftp_proxy = gnome_config_get_string ("/galeon/Advanced/ftp_proxy=");
-	ftp_proxy_port = gnome_config_get_int ("/galeon/Advanced/ftp_proxy_port=8080");
-	no_proxies_for = gnome_config_get_string ("/galeon/Advanced/no_proxies_for=localhost");
-	proxy_keepalive = gnome_config_get_bool ("/galeon/Advanced/proxy_keepalive=TRUE");
+		http_proxy = gnome_config_get_string ("/galeon/Advanced/http_proxy=");
+		http_proxy_port = gnome_config_get_int ("/galeon/Advanced/http_proxy_port=8080");
+		ssl_proxy = gnome_config_get_string("/galeon/Advanced/ssl_proxy=");
+		ssl_proxy_port = gnome_config_get_int("/galeon/Advanced/ssl_proxy_port=8080");
+		ftp_proxy = gnome_config_get_string ("/galeon/Advanced/ftp_proxy=");
+		ftp_proxy_port = gnome_config_get_int ("/galeon/Advanced/ftp_proxy_port=8080");
+		no_proxies_for = gnome_config_get_string ("/galeon/Advanced/no_proxies_for=localhost");
+		proxy_keepalive = gnome_config_get_bool ("/galeon/Advanced/proxy_keepalive=TRUE");
 
 
-	if (strlen (http_proxy) != 0)
-	{
-		mozilla_preference_set_int ("network.proxy.type", 1);
-		mozilla_preference_set ("network.proxy.http", http_proxy);
-		mozilla_preference_set_int ("network.proxy.http_port",
-					    http_proxy_port);
-	}
-
-	if (strlen (ssl_proxy) != 0)
-	{
-		mozilla_preference_set_int ("network.proxy.type", 1);
-		mozilla_preference_set ("network.proxy.ssl", ssl_proxy);
-		mozilla_preference_set_int ("network.proxy.ssl_port",
-					    ssl_proxy_port);
-	}
-
-	if (strlen (ftp_proxy) != 0)
-	{
-		mozilla_preference_set_int ("network.proxy.type", 1);
-		mozilla_preference_set ("network.proxy.ftp", ftp_proxy);
-		mozilla_preference_set_int ("network.proxy.ftp_port",
-					    ftp_proxy_port);
-	}
-
-	if ( (strlen (http_proxy) != 0) || (strlen (ftp_proxy) != 0) ||
-	     (strlen (ssl_proxy) != 0) )
-	{
-	        if (strlen (no_proxies_for) != 0) 
+		if (strlen (http_proxy) != 0)
 		{
-		  mozilla_preference_set ("network.proxy.no_proxies_on",
-					  no_proxies_for);
-		}
-		else
+			mozilla_preference_set_int ("network.proxy.type", 1);
+			mozilla_preference_set ("network.proxy.http", http_proxy);
+			mozilla_preference_set_int ("network.proxy.http_port",
+						    http_proxy_port);
+		} 
+
+		if (strlen (ssl_proxy) != 0)
 		{
-		/* Fix problem with changing to blank entry on the fly in prefs */
-		  mozilla_preference_set ("network.proxy.no_proxies_on", " ");
+			mozilla_preference_set_int ("network.proxy.type", proxy_enabled);
+			mozilla_preference_set ("network.proxy.ssl", ssl_proxy);
+			mozilla_preference_set_int ("network.proxy.ssl_port",
+						    ssl_proxy_port);
 		}
+
+		if (strlen (ftp_proxy) != 0)
+		{
+			mozilla_preference_set_int ("network.proxy.type", proxy_enabled);
+			mozilla_preference_set ("network.proxy.ftp", ftp_proxy);
+			mozilla_preference_set_int ("network.proxy.ftp_port",
+						    ftp_proxy_port);
+		}
+
+		if ( (strlen (http_proxy) != 0) || (strlen (ftp_proxy) != 0) ||
+	  	     (strlen (ssl_proxy) != 0) )
+		{
+	        
+			if (strlen (no_proxies_for) != 0) 
+			{
+		  		mozilla_preference_set ("network.proxy.no_proxies_on",
+							  no_proxies_for);
+			}
+			else
+			{
+			/* Fix problem with changing to blank entry on the fly in prefs */
+		  	mozilla_preference_set ("network.proxy.no_proxies_on", " ");
+			}
+		}
+
+		mozilla_preference_set_boolean("network.http.proxy.keep-alive",
+					       proxy_keepalive);
+
+		g_free (http_proxy);
+		g_free (ssl_proxy);
+		g_free (ftp_proxy);
+		g_free (no_proxies_for);
+	} else {
+		mozilla_preference_set_int ("network.proxy.type", 0); // no proxy
 	}
-
-	mozilla_preference_set_boolean("network.http.proxy.keep-alive",
-				       proxy_keepalive);
-
-	g_free (http_proxy);
-	g_free (ssl_proxy);
-	g_free (ftp_proxy);
-	g_free (no_proxies_for);
 }
 
 /**
