@@ -65,11 +65,15 @@ typedef struct
 	GtkWidget *tabbed_enable_check;
 	GtkWidget *tabbed_popups_enable_check;
 	GtkWidget *tabbed_autojump_check;
-	GtkWidget *tabbed_position_optionmenu;
 	GtkWidget *tabbed_shorten_spin;
+	GtkWidget *tabbed_position_optionmenu;
+	GtkWidget *tabbed_separator_check;
+	GtkWidget *tabbed_vowel_check;
+	GtkWidget *tabbed_prefix_check;
 	GtkWidget *completion_enable_optionmenu;
 	GtkWidget *completion_sort_optionmenu;
 	GtkWidget *show_spinner_check;
+        GtkWidget *proxy_use_checkbutton;
 	GtkWidget *http_proxy_entry;
 	GtkWidget *ssl_proxy_entry;
 	GtkWidget *ftp_proxy_entry;
@@ -100,6 +104,7 @@ typedef struct
 	GtkWidget *syntax_highlighting_checkbutton;
 	GtkWidget *crash_optionmenu;
 	GtkWidget *newwindows_optionmenu;
+	GtkWidget *statusbar_rewrite_check;
 	GtkWidget *windows_title_entry;
 	GtkWidget *fullscreen_stacking_checkbutton;
 	GtkWidget *myportal_stylesheet_entry;
@@ -212,6 +217,8 @@ preferences_apply (void)
 	toolbar_global_recreate ();  
 	set_settings_menu_global ();
 
+	/* FIXME: add code here to update all of the notebook labels */
+
 	tab_pos = gnome_config_get_int (CONF_APPEARANCE_TABBED_POSITION);
 	for (w = all_windows; w != NULL; w = g_list_next (w))
 	{
@@ -221,6 +228,28 @@ preferences_apply (void)
 	}
 }
 
+/**
+ * preferences_help: show the prefs Galeon manual page   
+ */
+void
+preferences_help (void)
+{
+	GnomeHelpMenuEntry pref_help = { "galeon", "preferences.html" };
+	gchar *file = NULL;
+
+	/* Try to find the preferences help page.  If we fail, use ghelp
+	   to load the index, instead */
+	file = gnome_help_file_find_file("galeon", "preferences.html");
+
+	if (file)
+	        gnome_help_display (NULL, &pref_help);
+	else
+		gnome_help_goto (NULL, "ghelp:galeon");
+
+	g_free(file);
+}
+
+
 /* default MIME types */
 struct { gchar *name; MimeAction action; } default_mimetypes[] =
 {
@@ -426,6 +455,10 @@ preferences_set_config_to_dialog(GtkWidget *widget)
 	set_config_from_optionmenu(pw.tabbed_position_optionmenu, 
 				   "tabbed_position");
 	set_config_from_spin_button(pw.tabbed_shorten_spin, "tabbed_shorten");
+	set_config_from_togglebutton(pw.tabbed_separator_check,
+				     "tabbed_separator");
+	set_config_from_togglebutton(pw.tabbed_vowel_check, "tabbed_vowel");
+	set_config_from_togglebutton(pw.tabbed_prefix_check, "tabbed_prefix");
 	set_config_from_optionmenu(pw.location_optionmenu, "url_location");
 	set_config_from_optionmenu(pw.toolbar_optionmenu, "toolbar_type");
 	set_config_from_fontpicker(pw.serif_font_fpicker, "serif_font");
@@ -499,6 +532,7 @@ preferences_set_config_to_dialog(GtkWidget *widget)
  
         /* process advanced preferences */
 	gnome_config_push_prefix("/galeon/Advanced/");
+	set_config_from_togglebutton(pw.proxy_use_checkbutton, "proxy_enabled");
 	set_config_from_editable(pw.http_proxy_entry, "http_proxy");
 	set_config_from_editable(pw.ssl_proxy_entry, "ssl_proxy");
 	set_config_from_editable(pw.ftp_proxy_entry, "ftp_proxy");
@@ -514,8 +548,10 @@ preferences_set_config_to_dialog(GtkWidget *widget)
 	set_config_from_optionmenu(pw.java_optionmenu, "java_enabled");
 	set_config_from_optionmenu(pw.javascript_optionmenu,
 				   "javascript_enabled");
-	set_config_from_spin_button(pw.history_expire_spin, "history_expire");
+       	set_config_from_spin_button(pw.history_expire_spin, "history_expire");
 	set_config_from_optionmenu(pw.image_optionmenu, "image_loading_type");
+	set_config_from_togglebutton(pw.statusbar_rewrite_check,
+				   "statusbar_rewrite");
 	set_config_from_optionmenu(pw.crash_optionmenu, "crash_recovery");
 	set_config_from_optionmenu(pw.autodetect_charset_optionmenu,
 				   "autodetect_charset");
@@ -698,6 +734,12 @@ preferences_set_dialog_to_config(GtkWidget *widget)
 				   "tabbed_position=2");
 	set_spin_button_from_config(pw.tabbed_shorten_spin,
 				    "tabbed_shorten=30");
+	set_togglebutton_from_config(pw.tabbed_separator_check,
+				    "tabbed_separator=TRUE");
+	set_togglebutton_from_config(pw.tabbed_vowel_check,
+				    "tabbed_vowel=FALSE");
+	set_togglebutton_from_config(pw.tabbed_prefix_check,
+				    "tabbed_prefix=TRUE");
 	set_optionmenu_from_config(pw.location_optionmenu, "url_location=1");
 	set_optionmenu_from_config(pw.toolbar_optionmenu, "toolbar_type=2");
 	set_fontpicker_from_config(pw.serif_font_fpicker,
@@ -772,13 +814,15 @@ preferences_set_dialog_to_config(GtkWidget *widget)
 				      "use_external_source_viewer=FALSE");
 	set_editable_from_config (pw.external_source_viewer_entry, 
 				  "external_source_viewer=gnome-edit");
-	set_togglebutton_from_config (pw.mime_enable_check, "mime_enable=TRUE");
+	set_togglebutton_from_config (pw.mime_enable_check, "mime_enable=FALSE");
 	set_togglebutton_from_config (pw.syntax_highlighting_checkbutton,
 				      "enable_syntax_highlighting=FALSE");
 	gnome_config_pop_prefix();
  
         /* process advanced preferences */
 	gnome_config_push_prefix("/galeon/Advanced/");
+	set_togglebutton_from_config(pw.proxy_use_checkbutton,
+				     "proxy_enabled=FALSE");
 	set_editable_from_config(pw.http_proxy_entry, "http_proxy=");
 	set_editable_from_config(pw.ssl_proxy_entry, "ssl_proxy=");
 	set_editable_from_config(pw.ftp_proxy_entry, "ftp_proxy=");
@@ -805,6 +849,8 @@ preferences_set_dialog_to_config(GtkWidget *widget)
 				    "history_expire=100");
 	set_optionmenu_from_config(pw.image_optionmenu,
 				   "image_loading_type=0");
+	set_togglebutton_from_config(pw.statusbar_rewrite_check,
+				  "statusbar_rewrite=TRUE");
 	set_optionmenu_from_config(pw.crash_optionmenu, "crash_recovery=1");
 	set_optionmenu_from_config(pw.autodetect_charset_optionmenu,
 				   "autodetect_charset=0");
@@ -969,6 +1015,7 @@ set_settings_menu_window (GaleonWindow *window)
 	gboolean enable_java;
 	gboolean enable_javascript;
 	gboolean enable_mime;
+	gboolean proxy_enabled;
 
 	load_images = gnome_config_get_int (CONF_ADVANCED_IMAGE_LOADING_TYPE);
 	animate = gnome_config_get_int (CONF_ADVANCED_ANIMATE_TYPE);
@@ -981,6 +1028,7 @@ set_settings_menu_window (GaleonWindow *window)
 	enable_javascript = 
 		gnome_config_get_int (CONF_ADVANCED_JAVASCRIPT_ENABLED);
 	enable_mime = gnome_config_get_bool (CONF_HANDLERS_MIME_ENABLE);
+	proxy_enabled = gnome_config_get_bool (CONF_ADVANCED_PROXY_ENABLED);
 	
 	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (window->use_own_fonts),
 					use_own_fonts);
@@ -990,6 +1038,8 @@ set_settings_menu_window (GaleonWindow *window)
 					enable_java);
 	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (window->enable_javascript),
 					enable_javascript);
+	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (window->enable_proxy),
+					proxy_enabled);
 	gtk_check_menu_item_set_active
 		(GTK_CHECK_MENU_ITEM (window->use_galeon_mime_handling), enable_mime);
 	
@@ -1060,6 +1110,9 @@ tabbed_popups_enable_check:          Q("tabbed_popups_enable_check"),
 tabbed_autojump_check:               Q("tabbed_autojump_check"),
 tabbed_position_optionmenu:          Q("tabbed_position_optionmenu"),
 tabbed_shorten_spin:                 Q("tabbed_shorten_spin"),
+tabbed_separator_check:              Q("tabbed_separator_check"),
+tabbed_vowel_check:                  Q("tabbed_vowel_check"),
+tabbed_prefix_check:                 Q("tabbed_prefix_check"),
 completion_enable_optionmenu:        Q("completion_enable_optionmenu"),
 completion_sort_optionmenu:          Q("completion_sort_optionmenu"),
 show_spinner_check:                  Q("show_spinner_checkbutton"),
@@ -1107,6 +1160,7 @@ visited_link_color:                  Q("visited_link_color"),
 use_provided_colors_optionmenu:      Q("use_provided_colors_optionmenu"),
 underline_links_checkbutton:         Q("underline_links_checkbutton"),
 proxy_keepalive_checkbutton:         Q("proxy_keepalive_checkbutton"),
+proxy_use_checkbutton:         	     Q("proxy_use_checkbutton"),
 http_version_optionmenu:             Q("http_version_optionmenu"),
 history_popup_checkbutton:           Q("history_popup_checkbutton"),
 middle_button_optionmenu:            Q("middle_button_optionmenu"),
@@ -1129,7 +1183,8 @@ wheel_shift_default_step_checkbutton:Q("wheel_shift_default_step_checkbutton"),
 crash_behaviour_optionmenu:          Q("crash_behaviour_optionmenu"),
 links_drag_checkbutton:              Q("links_drag_checkbutton"),
 nautilus_icons_checkbutton:          Q("nautilus_icons_checkbutton"),
-cache_compare_optionmenu:            Q("cache_compare_optionmenu")
+cache_compare_optionmenu:            Q("cache_compare_optionmenu"),
+statusbar_rewrite_check:             Q("statusbar_rewrite_check")
 	};
 #undef Q
 
@@ -1468,6 +1523,19 @@ preferences_set_enable_java (gboolean value)
 	}
 }
 
+void
+preferences_set_enable_proxy (gboolean value)
+{
+        gboolean old_value = gnome_config_get_bool (CONF_ADVANCED_PROXY_ENABLED);
+        if (value != old_value) {
+                gnome_config_set_bool (CONF_ADVANCED_PROXY_ENABLED, value);
+                gnome_config_sync ();
+                mozilla_prefs_set ();
+                set_settings_menu_global ();
+        }
+}
+
+
 void
 preferences_set_use_provided_fonts (gboolean value)
 {	
@@ -1515,7 +1583,7 @@ preferences_set_handlers_enable_mime (gboolean value)
 	gboolean new_value = value;
 	gboolean old_value = gnome_config_get_bool (CONF_HANDLERS_MIME_ENABLE);
 	if (new_value != old_value) {
-		gnome_config_set_int (CONF_HANDLERS_MIME_ENABLE, new_value);
+		gnome_config_set_bool (CONF_HANDLERS_MIME_ENABLE, new_value);
 		gnome_config_sync ();
 		set_settings_menu_global (); 
 	}
