@@ -25,6 +25,7 @@ void prefs_ctree_tree_unselect_row_cb (GtkWidget *ctree, GList *node,
 void prefs_ok_button_clicked_cb (GtkButton *button, GtkWidget *prefs);
 void prefs_apply_button_clicked_cb (GtkButton *button, GtkWidget *prefs);
 void prefs_cancel_button_clicked_cb (GtkButton *button, GtkWidget *prefs);
+void prefs_help_button_clicked_cb (GtkButton *button, GtkWidget *prefs);
 void prefs_mime_add_button_clicked_cb (GtkButton *button, GtkWidget *prefs);
 void prefs_mime_delete_button_clicked_cb (GtkButton *button, GtkWidget *prefs);
 void prefs_mime_edit_cb (GtkWidget *w, GtkWidget *prefs);
@@ -122,6 +123,13 @@ prefs_cancel_button_clicked_cb (GtkButton *button, GtkWidget *prefs_dlg)
 	prefs = NULL;
 }
 
+void
+prefs_help_button_clicked_cb (GtkButton *button, GtkWidget *prefs)
+{
+        preferences_help ();
+}
+
+
 /**
  * on_prefs_add_button_clicked: mime types add button clicked
  */
@@ -562,9 +570,12 @@ prefs_clear_history_question_cb (gint reply, gpointer data)
 		return;
 
 	/* clear the history list */
-	gtk_clist_freeze(clHistory);
-	gtk_clist_clear(clHistory);
-	gtk_clist_thaw(clHistory);
+	if (clHistory)
+	{
+		gtk_clist_freeze(clHistory);
+		gtk_clist_clear(clHistory);
+		gtk_clist_thaw(clHistory);
+	}
 
 	/* clear the hash table */
 	g_hash_table_freeze(history);
