@@ -1,4 +1,4 @@
-#/*
+/*
  *  Copyright (C) 2000 Marco Pesenti Gritti
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -17,6 +17,7 @@
  */
 
 #include "galeon.h"
+#include "menubar.h"
 
 /* indicates a window is in fullscreen mode */
 gboolean fullscreen_active = FALSE;
@@ -24,6 +25,9 @@ gboolean fullscreen_active = FALSE;
 /* local function prototypes */
 static void window_init_data (GaleonWindow *window);
 static void window_add_accelerators (GaleonWindow *window);
+static void window_set_menu_data (GaleonWindow *window);
+static void set_initial_window_properties (GaleonWindow *window, 
+					   gint width, gint height);
 
 /** The global list of all GaleonWindow structures */
 GList *all_windows = NULL;
@@ -61,6 +65,24 @@ window_load_url (GaleonWindow *window, const gchar *url)
 	/* load into the active GaleonEmbed */
 	embed_load_url (window->active_embed, url);
 }
+ 
+static void
+set_initial_window_properties (GaleonWindow *window, gint width, gint height)
+{
+	guint sane_width, sane_height;
+ 
+	sane_width = MIN (width, gdk_screen_width ());
+	sane_height = MIN (height, gdk_screen_height ());
+
+	gtk_window_set_default_size (GTK_WINDOW (window->WMain), 
+				     sane_width, sane_height);
+
+	gtk_window_set_policy (GTK_WINDOW (window->WMain), 
+			       TRUE, TRUE, FALSE);
+
+	gtk_window_set_wmclass (GTK_WINDOW (window->WMain), "",
+				"galeon_browser");
+}
 
 /**
  * window_create: create a browser structure and main window, 
@@ -71,24 +93,30 @@ GaleonWindow *
 window_create (void)
 {
         GaleonWindow *window;
-	GladeXML *gxml;
 	GnomeEntry *ge;
+	GtkWidget *bookmarks_item;
 	gint width, height;
-	gboolean menubar_relief;
-	gboolean menubar_detachable;
 	gint tab_pos;
-
-	/* use libglade to build the window */
-	gxml = glade_xml_new (glade_file (), "WMain");
  
 	/* allocate and initialise the GaleonWindow structure */
 	window = g_new0 (GaleonWindow, 1);
-	window->WMain = glade_xml_get_widget (gxml, "WMain");
-  	window_init_data (window);
 
-	/* don't know why libglade does not set this */
-	GNOME_APP(window->WMain)->menubar = 
-		glade_xml_get_widget (gxml, "menubar"); 
+	/* set magic */
+	window->magic = GALEON_WINDOW_MAGIC;
+
+	/* create the browser window */
+	window->WMain = gnome_app_new ("Galeon", _("Galeon"));
+
+	/* need to set the user_data field in all the GnomeUIInfo structs */
+	window_set_menu_data (window);
+
+	/* create the menus and statusbar */
+	gnome_app_create_menus (GNOME_APP(window->WMain), menubar_uiinfo);
+	gnome_app_set_statusbar (GNOME_APP(window->WMain),
+				 gnome_appbar_new (TRUE, TRUE,
+						   GNOME_PREFERENCES_NEVER));
+  	window_init_data (window);
+	gnome_app_install_menu_hints (GNOME_APP(window->WMain), menubar_uiinfo);
 
 	/* set mini icon */
 	gnome_window_icon_set_from_file (GTK_WINDOW (window->WMain), 
@@ -98,33 +126,28 @@ window_create (void)
 	gtk_object_set_data (GTK_OBJECT (window->WMain), "GaleonWindow",
 			     window);
 
-	/* set menubar relief according to gnome prefs (libglade does not)*/
-	menubar_relief = gnome_preferences_get_menubar_relief ();
-	gnome_dock_item_set_shadow_type 
-		(GNOME_DOCK_ITEM (window->menubar->parent), 
-		 menubar_relief ? GTK_SHADOW_OUT : GTK_SHADOW_NONE);
-
-	/* set the menubar detatchable state (FIXME: this is a hack) */
-	menubar_detachable = gnome_preferences_get_menubar_detachable ();
-	if (!menubar_detachable)
-	{
-		GNOME_DOCK_ITEM (window->menubar->parent)->behavior |=
-			GNOME_DOCK_ITEM_BEH_LOCKED;
-	}
-
-	/* connect the signals */
-	glade_xml_signal_autoconnect_full (gxml, (GladeXMLConnectFunc) 
-					   glade_signal_connect_func, window);
+	/* connect the delete signal handler*/
+	gtk_signal_connect(GTK_OBJECT(window->WMain), "delete-event",
+			   GTK_SIGNAL_FUNC(window_delete_cb),
+			   window);
 
 	/* create the toolbar */
 	toolbar_create (window);
 
+	/* set the initial state of the View_* CheckMenuItems */
+	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(
+						window->view_menubar), TRUE);
+	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(
+						window->view_toolbar), TRUE);
+	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(
+						window->view_statusbar), TRUE);
+
 	/* find the default width and height */
 	width = gnome_config_get_int (CONF_APPEARANCE_WINWIDTH);
 	height = gnome_config_get_int (CONF_APPEARANCE_WINHEIGHT);
 
-	/* set window default size */
-	gtk_widget_set_usize (GTK_WIDGET (window->WMain), width, height);
+	/* set initial window properties */
+	set_initial_window_properties (window, width, height);
 
 	/* add it to the list of windows */
 	all_windows = g_list_append(all_windows, window);
@@ -146,14 +169,13 @@ window_create (void)
 		 GDK_ACTION_COPY);
 
 	/* set bookmark menuitem drop destination */
-	gtk_drag_dest_set (glade_xml_get_widget (gxml, "bookmarks"), 
-			   GTK_DEST_DEFAULT_ALL,
+	bookmarks_item = gtk_object_get_data(GTK_OBJECT(window->WMain),
+					     "bookmarks");
+	gtk_drag_dest_set (bookmarks_item, GTK_DEST_DEFAULT_ALL,
 			   url_drag_types, url_drag_types_num_items,
 			   GDK_ACTION_COPY);
-	gtk_signal_connect (GTK_OBJECT 
-			    (glade_xml_get_widget (gxml, "bookmarks")), 
-			    "drag_data_received",
-			    GTK_SIGNAL_FUNC 
+	gtk_signal_connect (GTK_OBJECT(bookmarks_item), "drag_data_received",
+			    GTK_SIGNAL_FUNC
 			    (bookmarks_menuitem_drag_data_received_cb),
 			    window);
 
@@ -172,7 +194,9 @@ window_create (void)
 			    NULL);
 
 	/* add additional accelerators */
-	window_add_accelerators (window);
+	/* Note: Menu accelerators are now saved/restored, so this
+	   should no longer be necessary.  --Josh  */
+//	window_add_accelerators (window);
 
 	/* make the toplevel notebobok */
 	window->notebook = gtk_notebook_new ();
@@ -187,9 +211,6 @@ window_create (void)
 	gtk_notebook_set_show_tabs (GTK_NOTEBOOK (window->notebook), FALSE);
 	gtk_notebook_set_show_border (GTK_NOTEBOOK (window->notebook), FALSE);
 
-	/* set magic */
-	window->magic = GALEON_WINDOW_MAGIC;
-
 	/* insert notebook into toplevel window */
 	gnome_app_set_contents (GNOME_APP (window->WMain), 
 				GTK_WIDGET (window->notebook));
@@ -372,33 +393,64 @@ window_init_data (GaleonWindow *window)
 	window->bookmarks_toolbars = NULL;
 	window->bookmarks_tooltips = NULL;
 
-	/* local macro for looking up widgets */
-#define LOOKUP(name) \
-        window->name = glade_lookup_widget (window->WMain, #name);
+	window->dock = GNOME_APP(window->WMain)->dock;
+	window->appbar = GNOME_APP(window->WMain)->statusbar;
+	window->menubar = GNOME_APP(window->WMain)->menubar;
 
-	/* look these up */
-	LOOKUP(dock);
-	LOOKUP(appbar);
-	LOOKUP(menubar);
-	LOOKUP(view_source_mode);
-	LOOKUP(view_toolbar);
-	LOOKUP(view_menubar);
-	LOOKUP(view_statusbar);
-	LOOKUP(view_fullscreen);
-	LOOKUP(load_images_always);
-	LOOKUP(load_images_from_current_server_only);
-	LOOKUP(load_images_never);
-	LOOKUP(animate_always);
-	LOOKUP(animate_once_through);
-	LOOKUP(animate_never);
-	LOOKUP(use_own_fonts);
-	LOOKUP(use_own_colors);
-	LOOKUP(enable_java);
-	LOOKUP(enable_javascript);
-	LOOKUP(use_galeon_mime_handling);
+	window->view_source_mode = view_menu_uiinfo[1].widget;
+	window->view_menubar = view_menu_uiinfo[3].widget;
+	window->view_toolbar = view_menu_uiinfo[4].widget;
+	window->view_statusbar = view_menu_uiinfo[5].widget;
 
-        /* lose local macro */
-#undef LOOKUP
+	window->view_fullscreen = view_menu_uiinfo[6].widget;
+	window->load_images_always = load_images_always_uiinfo[0].widget;
+	window->load_images_from_current_server_only = 
+					load_images_always_uiinfo[1].widget;
+	window->load_images_never = load_images_always_uiinfo[2].widget;
+	window->animate_always = animate_always_uiinfo[0].widget;
+	window->animate_once_through = animate_always_uiinfo[1].widget;
+	window->animate_never = animate_always_uiinfo[2].widget;
+	window->use_own_fonts =  settings_menu_uiinfo[4].widget;
+	window->use_own_colors = settings_menu_uiinfo[5].widget;
+	window->enable_java = settings_menu_uiinfo[6].widget;
+	window->enable_javascript = settings_menu_uiinfo[7].widget;
+	window->enable_proxy = settings_menu_uiinfo[8].widget;
+	window->use_galeon_mime_handling = settings_menu_uiinfo[9].widget;
+
+	gtk_object_set_data(GTK_OBJECT(window->WMain), "WMain",
+			    window->WMain);
+
+	gtk_widget_ref(menubar_uiinfo[4].widget);
+	gtk_object_set_data_full(GTK_OBJECT(window->WMain), "bookmarks",
+					    menubar_uiinfo[4].widget,
+					   (GtkDestroyNotify) gtk_widget_unref);
+
+	gtk_widget_ref(GTK_MENU_ITEM(menubar_uiinfo[4].widget)->submenu);
+	gtk_object_set_data_full(GTK_OBJECT(window->WMain), "bookmarks_menu",
+			GTK_MENU_ITEM(menubar_uiinfo[4].widget)->submenu,
+			(GtkDestroyNotify) gtk_widget_unref);
+
+	gtk_widget_ref(GTK_MENU_ITEM(menubar_uiinfo[5].widget)->submenu);
+	gtk_object_set_data_full(GTK_OBJECT(window->WMain), "go_menu",
+			GTK_MENU_ITEM(menubar_uiinfo[5].widget)->submenu,
+			(GtkDestroyNotify) gtk_widget_unref);
+
+	gtk_widget_ref(bookmarks_menu_uiinfo[0].widget);
+	gtk_object_set_data_full(GTK_OBJECT(window->WMain), "file_bookmark",
+				 bookmarks_menu_uiinfo[0].widget,
+				 (GtkDestroyNotify) gtk_widget_unref);
+
+	gtk_widget_ref(bookmarks_menu_uiinfo[5].widget);
+	gtk_object_set_data_full(GTK_OBJECT(window->WMain),
+				 "bookmarks_separator",
+				 bookmarks_menu_uiinfo[5].widget,
+				 (GtkDestroyNotify) gtk_widget_unref);
+
+	gtk_widget_ref(view_menu_uiinfo[11].widget);
+	gtk_object_set_data_full(GTK_OBJECT(window->WMain),
+				 "encoding_menu_item",
+				 view_menu_uiinfo[11].widget,
+				 (GtkDestroyNotify) gtk_widget_unref);
 }
 
 /**
@@ -406,15 +458,9 @@ window_init_data (GaleonWindow *window)
  */
 void window_show_open_dialog(GaleonWindow *window)
 {
-	static GtkWidget *fs = NULL;
+	GtkWidget *fs = NULL;
 	GladeXML *gxml;
 
-	if (GTK_IS_WIDGET(fs))
-	{
-		gdk_window_raise(fs->window);
-		return;
-	}
-
 	gxml = glade_xml_new(glade_file(), "fsopen");
 	glade_xml_signal_autoconnect_full (gxml, glade_signal_connect_func,
 					   window);
@@ -423,6 +469,7 @@ void window_show_open_dialog(GaleonWindow *window)
 	gtk_file_selection_set_filename(GTK_FILE_SELECTION(fs),
 					gnome_config_get_string(CONF_DIR_OPEN));
 
+	gtk_window_set_modal(GTK_WINDOW(fs), TRUE);
 	gtk_widget_show(fs);
 	window_set_layer(fs);
 }
@@ -504,7 +551,9 @@ void window_show_temporary_bookmarks (GaleonWindow *window)
 	}
 	gtk_widget_show (temp_bookmarks_window->dialog);
 	window_set_layer(temp_bookmarks_window->dialog);
-	temp_bookmarks_window->embed = window->active_embed;
+
+	if (window)
+		temp_bookmarks_window->embed = window->active_embed;
 }
 
 /**
@@ -660,34 +709,44 @@ window_go_home(GaleonWindow *window, gboolean new_embed, gboolean new_window)
 
 	g_free(startpage);
 }
+
 /**
- * Add additional accelerators. Remember to keep in sync with 
- * mozembed_dom_key_press_cb
+ * Add additional accelerators.
+ *
  */
 static void
 window_add_accelerators (GaleonWindow *window)
 {
-	GladeXML *gxml = glade_get_widget_tree (window->WMain);
+#define NEW_WIN  file_menu_uiinfo[0].widget
+#define RELOAD   go_menu_uiinfo[2].widget
+#define ZOOM_IN  view_menu_uiinfo[8].widget
+#define ZOOM_OUT view_menu_uiinfo[9].widget
 	GtkAccelGroup *ag = GNOME_APP (window->WMain)->accel_group;
 	int i;
 	struct {
-		gchar *widget_name;
+		GtkWidget *widget;
 		gchar *signal_name;
 		guint key;
 		guint mods;
 		GtkAccelFlags flags;
 	} accelerators[] = {
-		{ "new_window_menuitem", "activate", GDK_n, GDK_MOD1_MASK, GTK_ACCEL_VISIBLE },
-		{ "reload_page_menuitem", "activate", GDK_r, GDK_MOD1_MASK, GTK_ACCEL_VISIBLE },
-		{ "zoom_in_menuitem", "activate", GDK_plus, GDK_MOD1_MASK, GTK_ACCEL_VISIBLE },
-		{ "zoom_out_menuitem", "activate", GDK_minus, GDK_MOD1_MASK, GTK_ACCEL_VISIBLE },
+		{ NEW_WIN, "activate",
+		  GDK_n, GDK_MOD1_MASK, GTK_ACCEL_VISIBLE },
+		{ RELOAD, "activate",
+		  GDK_r, GDK_MOD1_MASK, GTK_ACCEL_VISIBLE },
+		{ ZOOM_IN, "activate",
+		  GDK_plus, GDK_MOD1_MASK, GTK_ACCEL_VISIBLE },
+		{ ZOOM_OUT, "activate",
+		  GDK_minus, GDK_MOD1_MASK, GTK_ACCEL_VISIBLE },
 		{ NULL, NULL, 0, 0, 0 }
 	};
-	for (i = 0; accelerators[i].widget_name != NULL; i++) {
-		GtkWidget *w = glade_xml_get_widget (gxml, accelerators[i].widget_name);
-		gtk_widget_add_accelerator 
-			(w, accelerators[i].signal_name, ag, accelerators[i].key,
-			 accelerators[i].mods, accelerators[i].flags);
+	for (i = 0; accelerators[i].widget != NULL; i++) {
+		GtkWidget *w = (accelerators[i].widget);
+
+		gtk_widget_add_accelerator(w, accelerators[i].signal_name, ag,
+					   accelerators[i].key,
+					   accelerators[i].mods,
+					   accelerators[i].flags);
 	}
 }
 
@@ -720,9 +779,11 @@ window_set_encoding_menu (GaleonWindow *window, GList *charset_titles)
 {
 	GtkWidget *encoding_menu_item;
 
-	encoding_menu_item = glade_xml_get_widget (glade_get_widget_tree 
-		(window->menubar), "encoding_menu_item");
-	create_charset_submenus (GTK_MENU_ITEM(encoding_menu_item), charset_titles, window);
+	encoding_menu_item = gtk_object_get_data (GTK_OBJECT(window->WMain),
+						  "encoding_menu_item");
+
+	create_charset_submenus (GTK_MENU_ITEM(encoding_menu_item),
+				 charset_titles, window);
 }
 
 void
@@ -780,3 +841,51 @@ window_set_fullscreen_mode (GaleonWindow *window, gboolean active)
 		fullscreen_active = FALSE;
 	}
 }
+
+static void 
+window_set_menu_data (GaleonWindow *window)
+{
+	gint i, j, num_menus;
+
+	num_menus = sizeof(all_menus) / sizeof(GnomeUIInfo *);
+
+	for (i = 0; i < num_menus; i++)
+	{
+		for (j = 0; j < menus_num_items[i]; j++)
+		{
+			all_menus[i][j].user_data = window;
+		}
+	}
+}
+
+/* Use this function instead of glade_lookup_widget() to get the WMain
+   widget from one of its child widgets.  This is necessary because
+   libglade is no longer being used to create the main window */
+GtkWidget *
+window_lookup_wmain (GtkWidget *widget)
+{
+	GtkWidget *WMain = NULL;
+	GtkWidget *parent = NULL;
+
+	g_return_val_if_fail(widget != NULL, NULL);
+
+	while (!WMain)
+	{
+		WMain = gtk_object_get_data (GTK_OBJECT(widget), "WMain");
+
+		if (GTK_IS_MENU(widget))
+			parent = gtk_menu_get_attach_widget(GTK_MENU(widget));
+		else
+			parent = widget->parent;
+
+		if (parent == NULL)
+			break;
+
+		widget = parent;
+	}
+
+	if (!WMain)
+		g_warning("WMain not found.");
+
+	return WMain;
+}
